# to use this script, 
# example command to execute this script file
#   qsys-script --script=create_ghrd_qsys.tcl

# --- alternatively, input arguments could be passed in to select other FPGA variant. 
#     qsys_name    : <name your qsys top>,
#     devicefamily : <FPGA device family>,
#     device       : <FPGA device part number>
#     hps_sdram    : <FBGA code of memory device>
#     boot_device  : <selection of boot source, either SDMMC, QSPI, NAND, or FPGA>
#     hps_sdram_ecc: 1 or 0
#     hps_sgmii    : 1 or 0
#     fast_trace   : 1 or 0
#     fpga_dp      : 1 or 0
#     fpga_pcie    : 1 or 0
# example command to execute this script file
#   qsys-script --script=create_ghrd_qsys.tcl --cmd="set qsys_name soc_system; set devicefamily CYCLONEV; set device 5CSXFC6D6F31C8ES"

source ./design_config.tcl
    
if { ![ info exists devicefamily ] } {
  set devicefamily $DEVICE_FAMILY
} else {
  puts "-- Accepted parameter \$devicefamily = $devicefamily"
}
    
if { ![ info exists device ] } {
  set device $FPGA_DEVICE
} else {
  puts "-- Accepted parameter \$device = $device"
}
    
if { ![ info exists qsys_name ] } {
  set qsys_name $QSYS_NAME
} else {
  puts "-- Accepted parameter \$qsys_name = $qsys_name"
}

if { ![ info exists hps_sdram ] } {
  set hps_sdram $HPS_SDRAM_DEVICE
} else {
  puts "-- Accepted parameter \$hps_sdram = $hps_sdram"
}

if { ![ info exists hps_sdram_ecc ] } {
  set hps_sdram_ecc $HPS_SDRAM_ECC_ENABLE
} else {
  puts "-- Accepted parameter \$hps_sdram_ecc = $hps_sdram_ecc"
}

if { ![ info exists hps_sdram_debug_enable ] } {
  set hps_sdram_debug_enable $HPS_SDRAM_DEBUG_ENABLE
} else {
  puts "-- Accepted parameter \$hps_sdram_debug_enable = $hps_sdram_debug_enable"
}

if { ![ info exists hps_sgmii ] } {
  set hps_sgmii $SGMII_ENABLE
} else {
  puts "-- Accepted parameter \$hps_sgmii = $hps_sgmii"
}

if { ![ info exists fpga_dp ] } {
  set fpga_dp $DISP_PORT_ENABLE
} else {
  puts "-- Accepted parameter \$fpga_dp = $fpga_dp"
}

if { ![ info exists frame_reader ] } {
  set frame_reader $ADD_FRAME_READER
} else {
  puts "-- Accepted parameter \$frame_reader = $frame_reader"
}

if { ![ info exists fpga_pcie ] } {
  set fpga_pcie $GEN3_ENABLE
} else {
  puts "-- Accepted parameter \$fpga_pcie = $fpga_pcie"
}

if { ![ info exists boot_device ] } {
  set boot_device $BOOT_SOURCE
} else {
  puts "-- Accepted parameter \$boot_device = $boot_device"
}

if { ![ info exists fast_trace ] } {
  set fast_trace $FTRACE_ENABLE
} else {
  puts "-- Accepted parameter \$fast_trace = $fast_trace"
}


# Internal parameter derivation
if {$hps_sdram_ecc == 1} {
   set hps_sdram_width 40 
} else {
   set hps_sdram_width 32
}

if {$boot_device == "SDMMC"} {
set dedicated_io_assignment "SDMMC:D0 SDMMC:CMD SDMMC:CCLK SDMMC:D1 SDMMC:D2 SDMMC:D3 NONE NONE SDMMC:D4 SDMMC:D5 SDMMC:D6 SDMMC:D7 NONE NONE"
set boot_code 0
} elseif {$boot_device == "QSPI"} {
set dedicated_io_assignment "QSPI:CLK QSPI:IO0 QSPI:SS0 QSPI:IO1 QSPI:IO2_WPN QSPI:IO3_HOLD NONE NONE NONE NONE NONE NONE NONE NONE"
set boot_code 1
} elseif {$boot_device == "NAND"} {
set dedicated_io_assignment "NAND:ADQ0 NAND:ADQ1 NAND:WE_N NAND:RE_N NAND:ADQ2 NAND:ADQ3 NAND:CLE NAND:ALE NAND:RB NAND:CE_N NAND:ADQ4 NAND:ADQ5 NAND:ADQ6 NAND:ADQ7"
set boot_code 2
} else {
set dedicated_io_assignment "NONE NONE NONE NONE NONE NONE NONE NONE NONE NONE NONE NONE NONE NONE"
set boot_code 3
}

if {$hps_sdram == "D9RGX"} {
set hps_ddr 0
} elseif {$hps_sdram == "D9PZN"} {
set hps_ddr 1
} elseif {$hps_sdram == "D9RPL"} {
set hps_ddr 2
}

if {$fast_trace == 0 && $hps_sgmii == 0} {
set early_trace 1
} else {
set early_trace 0
}

if {$early_trace == 1} {
set etrace_data_assignment "TRACE:D0 TRACE:D1 TRACE:D2 TRACE:D3"
set etrace_clk_assignment "TRACE:CLK"
} else {
set etrace_data_assignment "unused unused unused unused"
set etrace_clk_assignment "unused"
}

set io48_q1_assignment "USB0:CLK USB0:STP USB0:DIR USB0:DATA0 USB0:DATA1 USB0:NXT USB0:DATA2 USB0:DATA3 USB0:DATA4 USB0:DATA5 USB0:DATA6 USB0:DATA7"
set io48_q2_assignment "EMAC0:TX_CLK EMAC0:TX_CTL EMAC0:RX_CLK EMAC0:RX_CTL EMAC0:TXD0 EMAC0:TXD1 EMAC0:RXD0 EMAC0:RXD1 EMAC0:TXD2 EMAC0:TXD3 EMAC0:RXD2 EMAC0:RXD3"
set io48_q3_assignment "SPIM1:CLK SPIM1:MOSI SPIM1:MISO SPIM1:SS0_N SPIM1:SS1_N GPIO UART1:TX UART1:RX NONE NONE MDIO0:MDIO MDIO0:MDC"

if {$hps_sgmii == 1} {
set io48_q4_assignment "unused unused unused $etrace_clk_assignment unused unused unused unused $etrace_data_assignment"
} else {
set io48_q4_assignment "I2C1:SDA I2C1:SCL GPIO $etrace_clk_assignment GPIO GPIO NONE NONE $etrace_data_assignment"
}

set variant_id [expr [expr $GEN3_ENABLE<<13] + [expr $CROSS_TRIGGER_ENABLE<<12] + [expr [expr $early_trace]<<11] + [expr $fast_trace<<10] + [expr $fpga_dp<<9] + [expr $hps_sgmii<<8] + [expr $boot_code<<4] + [expr $hps_sdram_ecc<<3] + $hps_ddr]
puts "VARIANT: [format %8.4x $variant_id]"

set SYSID [expr 0xA0030000 + $variant_id]
puts "SYSID  : [format %8.8x $SYSID]"

package require -exact qsys 14.1

if {$hps_sgmii == 1} {
#set sub_qsys_sgmii $sgmii_sub_system_name
source ./construct_subsys_sgmii.tcl 
reload_ip_catalog
}

if {$fpga_dp == 1} {
#set sub_qsys_dp $displayport_sub_system_name 
source ./construct_subsys_dp.tcl
reload_ip_catalog
}

if {$fpga_pcie == 1} {
source ./construct_subsys_pcie.tcl
reload_ip_catalog
}

create_system $qsys_name

  set_project_property DEVICE_FAMILY $devicefamily
  set_project_property DEVICE $device
  
  add_instance clk_0 clock_source
  set_instance_parameter_value clk_0 {clockFrequency} {100000000.0}
  set_instance_parameter_value clk_0 {clockFrequencyKnown} {1}
  set_instance_parameter_value clk_0 {resetSynchronousEdges} {DEASSERT}    
  
  if {$fpga_dp == 1} {
  add_instance clock_bridge_0 altera_clock_bridge
  set_instance_parameter_value clock_bridge_0 {EXPLICIT_CLOCK_RATE} {160000000.0}
  set_instance_parameter_value clock_bridge_0 {NUM_CLOCK_OUTPUTS} {1}
  }
  
  if {$fpga_pcie == 1} {
    add_instance pio_rp_reset altera_avalon_pio
    set_instance_parameter_value pio_rp_reset {bitClearingEdgeCapReg} {0}
    set_instance_parameter_value pio_rp_reset {bitModifyingOutReg} {0}
    set_instance_parameter_value pio_rp_reset {captureEdge} {0}
    set_instance_parameter_value pio_rp_reset {direction} {InOut}
    set_instance_parameter_value pio_rp_reset {edgeType} {RISING}
    set_instance_parameter_value pio_rp_reset {generateIRQ} {0}
    set_instance_parameter_value pio_rp_reset {irqType} {LEVEL}
    set_instance_parameter_value pio_rp_reset {resetValue} {0.0}
    set_instance_parameter_value pio_rp_reset {simDoTestBenchWiring} {0}
    set_instance_parameter_value pio_rp_reset {simDrivenValue} {0.0}
	set_instance_parameter_value pio_rp_reset {width} {1}
  
	add_instance iopll_0 altera_iopll
    set_instance_parameter_value iopll_0 {gui_device_speed_grade} {1}
    set_instance_parameter_value iopll_0 {gui_en_reconf} {0}
    set_instance_parameter_value iopll_0 {gui_en_dps_ports} {0}
    set_instance_parameter_value iopll_0 {gui_pll_mode} {Integer-N PLL}
    set_instance_parameter_value iopll_0 {gui_reference_clock_frequency} {250.0}
    set_instance_parameter_value iopll_0 {gui_fractional_cout} {32}
    set_instance_parameter_value iopll_0 {gui_dsm_out_sel} {1st_order}
    set_instance_parameter_value iopll_0 {gui_use_locked} {1}
    set_instance_parameter_value iopll_0 {gui_en_adv_params} {0}
    set_instance_parameter_value iopll_0 {gui_pll_bandwidth_preset} {Low}
    set_instance_parameter_value iopll_0 {gui_pll_auto_reset} {0}
    # set_instance_parameter_value iopll_0 {gui_en_lvds_ports} {0}
    set_instance_parameter_value iopll_0 {gui_operation_mode} {source synchronous}
    set_instance_parameter_value iopll_0 {gui_use_NDFB_modes} {0}
    set_instance_parameter_value iopll_0 {gui_refclk_switch} {0}
    set_instance_parameter_value iopll_0 {gui_refclk1_frequency} {100.0}
    set_instance_parameter_value iopll_0 {gui_en_phout_ports} {0}
    set_instance_parameter_value iopll_0 {gui_phout_division} {1}
    set_instance_parameter_value iopll_0 {gui_en_extclkout_ports} {0}
    set_instance_parameter_value iopll_0 {gui_number_of_clocks} {1}
    set_instance_parameter_value iopll_0 {gui_multiply_factor} {6}
    set_instance_parameter_value iopll_0 {gui_divide_factor_n} {1}
    set_instance_parameter_value iopll_0 {gui_frac_multiply_factor} {1.0}
    set_instance_parameter_value iopll_0 {gui_fix_vco_frequency} {0}
    set_instance_parameter_value iopll_0 {gui_fixed_vco_frequency} {600.0}
    set_instance_parameter_value iopll_0 {gui_vco_frequency} {600.0}
    set_instance_parameter_value iopll_0 {gui_enable_output_counter_cascading} {0}
    set_instance_parameter_value iopll_0 {gui_mif_generate} {0}
    set_instance_parameter_value iopll_0 {gui_active_clk} {0}
    set_instance_parameter_value iopll_0 {gui_clk_bad} {0}
    set_instance_parameter_value iopll_0 {gui_switchover_mode} {Automatic Switchover}
    set_instance_parameter_value iopll_0 {gui_switchover_delay} {0}
    set_instance_parameter_value iopll_0 {gui_enable_cascade_out} {0}
    set_instance_parameter_value iopll_0 {gui_cascade_outclk_index} {0}
    set_instance_parameter_value iopll_0 {gui_enable_cascade_in} {0}
    set_instance_parameter_value iopll_0 {gui_pll_cascading_mode} {adjpllin}
    set_instance_parameter_value iopll_0 {gui_enable_mif_dps} {0}
    set_instance_parameter_value iopll_0 {gui_dps_cntr} {C0}
    set_instance_parameter_value iopll_0 {gui_dps_num} {1}
    set_instance_parameter_value iopll_0 {gui_dps_dir} {Positive}
    set_instance_parameter_value iopll_0 {gui_extclkout_0_source} {C0}
    set_instance_parameter_value iopll_0 {gui_extclkout_1_source} {C0}
    set_instance_parameter_value iopll_0 {gui_clock_name_global0} {0}
    set_instance_parameter_value iopll_0 {gui_clock_name_global1} {0}
    set_instance_parameter_value iopll_0 {gui_clock_name_global2} {0}
    set_instance_parameter_value iopll_0 {gui_clock_name_global3} {0}
    set_instance_parameter_value iopll_0 {gui_clock_name_global4} {0}
    set_instance_parameter_value iopll_0 {gui_clock_name_global5} {0}
    set_instance_parameter_value iopll_0 {gui_clock_name_global6} {0}
    set_instance_parameter_value iopll_0 {gui_clock_name_global7} {0}
    set_instance_parameter_value iopll_0 {gui_clock_name_global8} {0}
    set_instance_parameter_value iopll_0 {gui_clock_name_global9} {0}
    set_instance_parameter_value iopll_0 {gui_clock_name_global10} {0}
    set_instance_parameter_value iopll_0 {gui_clock_name_global11} {0}
    set_instance_parameter_value iopll_0 {gui_clock_name_global12} {0}
    set_instance_parameter_value iopll_0 {gui_clock_name_global13} {0}
    set_instance_parameter_value iopll_0 {gui_clock_name_global14} {0}
    set_instance_parameter_value iopll_0 {gui_clock_name_global15} {0}
    set_instance_parameter_value iopll_0 {gui_clock_name_global16} {0}
    set_instance_parameter_value iopll_0 {gui_clock_name_global17} {0}
    set_instance_parameter_value iopll_0 {gui_clock_name_string0} {outclk0}
    set_instance_parameter_value iopll_0 {gui_clock_name_string1} {outclk1}
    set_instance_parameter_value iopll_0 {gui_clock_name_string2} {outclk2}
    set_instance_parameter_value iopll_0 {gui_clock_name_string3} {outclk3}
    set_instance_parameter_value iopll_0 {gui_clock_name_string4} {outclk4}
    set_instance_parameter_value iopll_0 {gui_clock_name_string5} {outclk5}
    set_instance_parameter_value iopll_0 {gui_clock_name_string6} {outclk6}
    set_instance_parameter_value iopll_0 {gui_clock_name_string7} {outclk7}
    set_instance_parameter_value iopll_0 {gui_clock_name_string8} {outclk8}
    set_instance_parameter_value iopll_0 {gui_clock_name_string9} {outclk9}
    set_instance_parameter_value iopll_0 {gui_clock_name_string10} {outclk10}
    set_instance_parameter_value iopll_0 {gui_clock_name_string11} {outclk11}
    set_instance_parameter_value iopll_0 {gui_clock_name_string12} {outclk12}
    set_instance_parameter_value iopll_0 {gui_clock_name_string13} {outclk13}
    set_instance_parameter_value iopll_0 {gui_clock_name_string14} {outclk14}
    set_instance_parameter_value iopll_0 {gui_clock_name_string15} {outclk15}
    set_instance_parameter_value iopll_0 {gui_clock_name_string16} {outclk16}
    set_instance_parameter_value iopll_0 {gui_clock_name_string17} {outclk17}
    set_instance_parameter_value iopll_0 {gui_divide_factor_c0} {6}
    set_instance_parameter_value iopll_0 {gui_divide_factor_c1} {6}
    set_instance_parameter_value iopll_0 {gui_divide_factor_c2} {6}
    set_instance_parameter_value iopll_0 {gui_divide_factor_c3} {6}
    set_instance_parameter_value iopll_0 {gui_divide_factor_c4} {6}
    set_instance_parameter_value iopll_0 {gui_divide_factor_c5} {6}
    set_instance_parameter_value iopll_0 {gui_divide_factor_c6} {6}
    set_instance_parameter_value iopll_0 {gui_divide_factor_c7} {6}
    set_instance_parameter_value iopll_0 {gui_divide_factor_c8} {6}
    set_instance_parameter_value iopll_0 {gui_divide_factor_c9} {6}
    set_instance_parameter_value iopll_0 {gui_divide_factor_c10} {6}
    set_instance_parameter_value iopll_0 {gui_divide_factor_c11} {6}
    set_instance_parameter_value iopll_0 {gui_divide_factor_c12} {6}
    set_instance_parameter_value iopll_0 {gui_divide_factor_c13} {6}
    set_instance_parameter_value iopll_0 {gui_divide_factor_c14} {6}
    set_instance_parameter_value iopll_0 {gui_divide_factor_c15} {6}
    set_instance_parameter_value iopll_0 {gui_divide_factor_c16} {6}
    set_instance_parameter_value iopll_0 {gui_divide_factor_c17} {6}
    set_instance_parameter_value iopll_0 {gui_cascade_counter0} {0}
    set_instance_parameter_value iopll_0 {gui_cascade_counter1} {0}
    set_instance_parameter_value iopll_0 {gui_cascade_counter2} {0}
    set_instance_parameter_value iopll_0 {gui_cascade_counter3} {0}
    set_instance_parameter_value iopll_0 {gui_cascade_counter4} {0}
    set_instance_parameter_value iopll_0 {gui_cascade_counter5} {0}
    set_instance_parameter_value iopll_0 {gui_cascade_counter6} {0}
    set_instance_parameter_value iopll_0 {gui_cascade_counter7} {0}
    set_instance_parameter_value iopll_0 {gui_cascade_counter8} {0}
    set_instance_parameter_value iopll_0 {gui_cascade_counter9} {0}
    set_instance_parameter_value iopll_0 {gui_cascade_counter10} {0}
    set_instance_parameter_value iopll_0 {gui_cascade_counter11} {0}
    set_instance_parameter_value iopll_0 {gui_cascade_counter12} {0}
    set_instance_parameter_value iopll_0 {gui_cascade_counter13} {0}
    set_instance_parameter_value iopll_0 {gui_cascade_counter14} {0}
    set_instance_parameter_value iopll_0 {gui_cascade_counter15} {0}
    set_instance_parameter_value iopll_0 {gui_cascade_counter16} {0}
    set_instance_parameter_value iopll_0 {gui_cascade_counter17} {0}
    set_instance_parameter_value iopll_0 {gui_output_clock_frequency0} {125.0}
    set_instance_parameter_value iopll_0 {gui_output_clock_frequency1} {100.0}
    set_instance_parameter_value iopll_0 {gui_output_clock_frequency2} {100.0}
    set_instance_parameter_value iopll_0 {gui_output_clock_frequency3} {100.0}
    set_instance_parameter_value iopll_0 {gui_output_clock_frequency4} {100.0}
    set_instance_parameter_value iopll_0 {gui_output_clock_frequency5} {100.0}
    set_instance_parameter_value iopll_0 {gui_output_clock_frequency6} {100.0}
    set_instance_parameter_value iopll_0 {gui_output_clock_frequency7} {100.0}
    set_instance_parameter_value iopll_0 {gui_output_clock_frequency8} {100.0}
    set_instance_parameter_value iopll_0 {gui_output_clock_frequency9} {100.0}
    set_instance_parameter_value iopll_0 {gui_output_clock_frequency10} {100.0}
    set_instance_parameter_value iopll_0 {gui_output_clock_frequency11} {100.0}
    set_instance_parameter_value iopll_0 {gui_output_clock_frequency12} {100.0}
    set_instance_parameter_value iopll_0 {gui_output_clock_frequency13} {100.0}
    set_instance_parameter_value iopll_0 {gui_output_clock_frequency14} {100.0}
    set_instance_parameter_value iopll_0 {gui_output_clock_frequency15} {100.0}
    set_instance_parameter_value iopll_0 {gui_output_clock_frequency16} {100.0}
    set_instance_parameter_value iopll_0 {gui_output_clock_frequency17} {100.0}
    set_instance_parameter_value iopll_0 {gui_actual_output_clock_frequency0} {100.0}
    set_instance_parameter_value iopll_0 {gui_actual_output_clock_frequency1} {100.0}
    set_instance_parameter_value iopll_0 {gui_actual_output_clock_frequency2} {100.0}
    set_instance_parameter_value iopll_0 {gui_actual_output_clock_frequency3} {100.0}
    set_instance_parameter_value iopll_0 {gui_actual_output_clock_frequency4} {100.0}
    set_instance_parameter_value iopll_0 {gui_actual_output_clock_frequency5} {100.0}
    set_instance_parameter_value iopll_0 {gui_actual_output_clock_frequency6} {100.0}
    set_instance_parameter_value iopll_0 {gui_actual_output_clock_frequency7} {100.0}
    set_instance_parameter_value iopll_0 {gui_actual_output_clock_frequency8} {100.0}
    set_instance_parameter_value iopll_0 {gui_actual_output_clock_frequency9} {100.0}
    set_instance_parameter_value iopll_0 {gui_actual_output_clock_frequency10} {100.0}
    set_instance_parameter_value iopll_0 {gui_actual_output_clock_frequency11} {100.0}
    set_instance_parameter_value iopll_0 {gui_actual_output_clock_frequency12} {100.0}
    set_instance_parameter_value iopll_0 {gui_actual_output_clock_frequency13} {100.0}
    set_instance_parameter_value iopll_0 {gui_actual_output_clock_frequency14} {100.0}
    set_instance_parameter_value iopll_0 {gui_actual_output_clock_frequency15} {100.0}
    set_instance_parameter_value iopll_0 {gui_actual_output_clock_frequency16} {100.0}
    set_instance_parameter_value iopll_0 {gui_actual_output_clock_frequency17} {100.0}
    set_instance_parameter_value iopll_0 {gui_ps_units0} {ps}
    set_instance_parameter_value iopll_0 {gui_ps_units1} {ps}
    set_instance_parameter_value iopll_0 {gui_ps_units2} {ps}
    set_instance_parameter_value iopll_0 {gui_ps_units3} {ps}
    set_instance_parameter_value iopll_0 {gui_ps_units4} {ps}
    set_instance_parameter_value iopll_0 {gui_ps_units5} {ps}
    set_instance_parameter_value iopll_0 {gui_ps_units6} {ps}
    set_instance_parameter_value iopll_0 {gui_ps_units7} {ps}
    set_instance_parameter_value iopll_0 {gui_ps_units8} {ps}
    set_instance_parameter_value iopll_0 {gui_ps_units9} {ps}
    set_instance_parameter_value iopll_0 {gui_ps_units10} {ps}
    set_instance_parameter_value iopll_0 {gui_ps_units11} {ps}
    set_instance_parameter_value iopll_0 {gui_ps_units12} {ps}
    set_instance_parameter_value iopll_0 {gui_ps_units13} {ps}
    set_instance_parameter_value iopll_0 {gui_ps_units14} {ps}
    set_instance_parameter_value iopll_0 {gui_ps_units15} {ps}
    set_instance_parameter_value iopll_0 {gui_ps_units16} {ps}
    set_instance_parameter_value iopll_0 {gui_ps_units17} {ps}
    set_instance_parameter_value iopll_0 {gui_phase_shift0} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift1} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift2} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift3} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift4} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift5} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift6} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift7} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift8} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift9} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift10} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift11} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift12} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift13} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift14} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift15} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift16} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift17} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift_deg0} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift_deg1} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift_deg2} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift_deg3} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift_deg4} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift_deg5} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift_deg6} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift_deg7} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift_deg8} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift_deg9} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift_deg10} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift_deg11} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift_deg12} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift_deg13} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift_deg14} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift_deg15} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift_deg16} {0.0}
    set_instance_parameter_value iopll_0 {gui_phase_shift_deg17} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift0} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift1} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift2} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift3} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift4} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift5} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift6} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift7} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift8} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift9} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift10} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift11} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift12} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift13} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift14} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift15} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift16} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift17} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift_deg0} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift_deg1} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift_deg2} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift_deg3} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift_deg4} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift_deg5} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift_deg6} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift_deg7} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift_deg8} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift_deg9} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift_deg10} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift_deg11} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift_deg12} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift_deg13} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift_deg14} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift_deg15} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift_deg16} {0.0}
    set_instance_parameter_value iopll_0 {gui_actual_phase_shift_deg17} {0.0}
    set_instance_parameter_value iopll_0 {gui_duty_cycle0} {50.0}
    set_instance_parameter_value iopll_0 {gui_duty_cycle1} {50.0}
    set_instance_parameter_value iopll_0 {gui_duty_cycle2} {50.0}
    set_instance_parameter_value iopll_0 {gui_duty_cycle3} {50.0}
    set_instance_parameter_value iopll_0 {gui_duty_cycle4} {50.0}
    set_instance_parameter_value iopll_0 {gui_duty_cycle5} {50.0}
    set_instance_parameter_value iopll_0 {gui_duty_cycle6} {50.0}
    set_instance_parameter_value iopll_0 {gui_duty_cycle7} {50.0}
    set_instance_parameter_value iopll_0 {gui_duty_cycle8} {50.0}
    set_instance_parameter_value iopll_0 {gui_duty_cycle9} {50.0}
    set_instance_parameter_value iopll_0 {gui_duty_cycle10} {50.0}
    set_instance_parameter_value iopll_0 {gui_duty_cycle11} {50.0}
    set_instance_parameter_value iopll_0 {gui_duty_cycle12} {50.0}
    set_instance_parameter_value iopll_0 {gui_duty_cycle13} {50.0}
    set_instance_parameter_value iopll_0 {gui_duty_cycle14} {50.0}
    set_instance_parameter_value iopll_0 {gui_duty_cycle15} {50.0}
    set_instance_parameter_value iopll_0 {gui_duty_cycle16} {50.0}
    set_instance_parameter_value iopll_0 {gui_duty_cycle17} {50.0}
    set_instance_parameter_value iopll_0 {gui_actual_duty_cycle0} {50.0}
    set_instance_parameter_value iopll_0 {gui_actual_duty_cycle1} {50.0}
    set_instance_parameter_value iopll_0 {gui_actual_duty_cycle2} {50.0}
    set_instance_parameter_value iopll_0 {gui_actual_duty_cycle3} {50.0}
    set_instance_parameter_value iopll_0 {gui_actual_duty_cycle4} {50.0}
    set_instance_parameter_value iopll_0 {gui_actual_duty_cycle5} {50.0}
    set_instance_parameter_value iopll_0 {gui_actual_duty_cycle6} {50.0}
    set_instance_parameter_value iopll_0 {gui_actual_duty_cycle7} {50.0}
    set_instance_parameter_value iopll_0 {gui_actual_duty_cycle8} {50.0}
    set_instance_parameter_value iopll_0 {gui_actual_duty_cycle9} {50.0}
    set_instance_parameter_value iopll_0 {gui_actual_duty_cycle10} {50.0}
    set_instance_parameter_value iopll_0 {gui_actual_duty_cycle11} {50.0}
    set_instance_parameter_value iopll_0 {gui_actual_duty_cycle12} {50.0}
    set_instance_parameter_value iopll_0 {gui_actual_duty_cycle13} {50.0}
    set_instance_parameter_value iopll_0 {gui_actual_duty_cycle14} {50.0}
    set_instance_parameter_value iopll_0 {gui_actual_duty_cycle15} {50.0}
    set_instance_parameter_value iopll_0 {gui_actual_duty_cycle16} {50.0}
    set_instance_parameter_value iopll_0 {gui_actual_duty_cycle17} {50.0}

  }
  
  add_instance reset_bridge_0 altera_reset_bridge
  set_instance_parameter_value reset_bridge_0 {ACTIVE_LOW_RESET} {0}
  set_instance_parameter_value reset_bridge_0 {SYNCHRONOUS_EDGES} {deassert}
  set_instance_parameter_value reset_bridge_0 {NUM_RESET_OUTPUTS} {1}
  set_instance_parameter_value reset_bridge_0 {USE_RESET_REQUEST} {0}
  
  add_instance arria10_hps_0 altera_arria10_hps 
  set_instance_parameter_value arria10_hps_0 {MPU_EVENTS_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {GP_Enable} {1}
  set_instance_parameter_value arria10_hps_0 {DEBUG_APB_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {STM_Enable} {1}
  set_instance_parameter_value arria10_hps_0 {CTI_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {BOOT_FROM_FPGA_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {JTAG_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {TEST_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {BSEL_EN} {0}
  set_instance_parameter_value arria10_hps_0 {BSEL} {1}
  set_instance_parameter_value arria10_hps_0 {F2S_Width} {3}
  set_instance_parameter_value arria10_hps_0 {S2F_Width} {1}
  set_instance_parameter_value arria10_hps_0 {LWH2F_Enable} {1}
  set_instance_parameter_value arria10_hps_0 {RUN_INTERNAL_BUILD_CHECKS} {0}
  set_instance_parameter_value arria10_hps_0 {F2SDRAM_PORT_CONFIG} {5}
  set_instance_parameter_value arria10_hps_0 {F2SDRAM0_ENABLED} {0}
  set_instance_parameter_value arria10_hps_0 {F2SDRAM1_ENABLED} {1}
  set_instance_parameter_value arria10_hps_0 {F2SDRAM2_ENABLED} {0}
  set_instance_parameter_value arria10_hps_0 {F2SDRAM_READY_LATENCY} {0}
  set_instance_parameter_value arria10_hps_0 {F2SDRAM_ADDRESS_WIDTH} {32}
  set_instance_parameter_value arria10_hps_0 {DMA_Enable} {No No No No No No No No}
  set_instance_parameter_value arria10_hps_0 {SECURITY_MODULE_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {EMAC0_SWITCH_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {EMAC1_SWITCH_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {EMAC2_SWITCH_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {F2SINTERRUPT_Enable} {1}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_CLOCKPERIPHERAL_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_CTI_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_DMA_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_EMAC0_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_EMAC1_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_EMAC2_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_FPGAMANAGER_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_GPIO_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_HMC_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_I2CEMAC0_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_I2CEMAC1_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_I2CEMAC2_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_I2C0_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_I2C1_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_L4TIMER_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_NAND_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_QSPI_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_SYSTIMER_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_SDMMC_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_SPIM0_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_SPIM1_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_SPIS0_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_SPIS1_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_SYSTEMMANAGER_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_UART0_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_UART1_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_USB0_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_USB1_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {S2FINTERRUPT_WATCHDOG_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {eosc1_clk_mhz} {25.0}
  set_instance_parameter_value arria10_hps_0 {F2H_FREE_CLK_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {F2H_FREE_CLK_FREQ} {200}
  set_instance_parameter_value arria10_hps_0 {FPGA_PERIPHERAL_OUTPUT_CLOCK_FREQ_EMAC0_MD_CLK} {2.5}
  set_instance_parameter_value arria10_hps_0 {FPGA_PERIPHERAL_OUTPUT_CLOCK_FREQ_EMAC0_GTX_CLK} {100}
  set_instance_parameter_value arria10_hps_0 {FPGA_PERIPHERAL_OUTPUT_CLOCK_FREQ_EMAC1_MD_CLK} {2.5}
  set_instance_parameter_value arria10_hps_0 {FPGA_PERIPHERAL_OUTPUT_CLOCK_FREQ_EMAC1_GTX_CLK} {125}
  set_instance_parameter_value arria10_hps_0 {FPGA_PERIPHERAL_OUTPUT_CLOCK_FREQ_EMAC2_MD_CLK} {2.5}
  set_instance_parameter_value arria10_hps_0 {FPGA_PERIPHERAL_OUTPUT_CLOCK_FREQ_EMAC2_GTX_CLK} {125}
  set_instance_parameter_value arria10_hps_0 {FPGA_PERIPHERAL_OUTPUT_CLOCK_FREQ_QSPI_SCLK_OUT} {100}
  set_instance_parameter_value arria10_hps_0 {FPGA_PERIPHERAL_OUTPUT_CLOCK_FREQ_SDMMC_CCLK} {100}
  set_instance_parameter_value arria10_hps_0 {FPGA_PERIPHERAL_OUTPUT_CLOCK_FREQ_SPIM0_SCLK_OUT} {100}
  set_instance_parameter_value arria10_hps_0 {FPGA_PERIPHERAL_OUTPUT_CLOCK_FREQ_SPIM1_SCLK_OUT} {100}
  set_instance_parameter_value arria10_hps_0 {FPGA_PERIPHERAL_OUTPUT_CLOCK_FREQ_I2C0_CLK} {100}
  set_instance_parameter_value arria10_hps_0 {FPGA_PERIPHERAL_OUTPUT_CLOCK_FREQ_I2C1_CLK} {100}
  set_instance_parameter_value arria10_hps_0 {FPGA_PERIPHERAL_OUTPUT_CLOCK_FREQ_I2CEMAC0_CLK} {100}
  set_instance_parameter_value arria10_hps_0 {FPGA_PERIPHERAL_OUTPUT_CLOCK_FREQ_I2CEMAC1_CLK} {100}
  set_instance_parameter_value arria10_hps_0 {FPGA_PERIPHERAL_OUTPUT_CLOCK_FREQ_I2CEMAC2_CLK} {100}
  set_instance_parameter_value arria10_hps_0 {USE_DEFAULT_MPU_CLK} {1}
  set_instance_parameter_value arria10_hps_0 {CUSTOM_MPU_CLK} {1020}
  set_instance_parameter_value arria10_hps_0 {H2F_USER0_CLK_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {H2F_USER0_CLK_FREQ} {400}
  set_instance_parameter_value arria10_hps_0 {H2F_USER1_CLK_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {H2F_USER1_CLK_FREQ} {400}
  set_instance_parameter_value arria10_hps_0 {HMC_PLL_REF_CLK} {800}
  set_instance_parameter_value arria10_hps_0 {EMAC_PTP_REF_CLK} {100}
  set_instance_parameter_value arria10_hps_0 {SDMMC_REF_CLK} {200}
  set_instance_parameter_value arria10_hps_0 {GPIO_REF_CLK} {4}
  set_instance_parameter_value arria10_hps_0 {L3_MAIN_FREE_CLK} {340}
  set_instance_parameter_value arria10_hps_0 {L4_SYS_FREE_CLK} {1}
  set_instance_parameter_value arria10_hps_0 {NOCDIV_L4MAINCLK} {0}
  set_instance_parameter_value arria10_hps_0 {NOCDIV_L4MPCLK} {1}
  set_instance_parameter_value arria10_hps_0 {NOCDIV_L4SPCLK} {2}
  set_instance_parameter_value arria10_hps_0 {NOCDIV_CS_ATCLK} {1}
  set_instance_parameter_value arria10_hps_0 {NOCDIV_CS_PDBGCLK} {1}
  set_instance_parameter_value arria10_hps_0 {NOCDIV_CS_TRACECLK} {1}
  set_instance_parameter_value arria10_hps_0 {HPS_DIV_GPIO_FREQ} {125}
  set_instance_parameter_value arria10_hps_0 {EMAC0_CLK} {250}
  set_instance_parameter_value arria10_hps_0 {EMAC1_CLK} {250}
  set_instance_parameter_value arria10_hps_0 {EMAC2_CLK} {250}
  set_instance_parameter_value arria10_hps_0 {DISABLE_PERI_PLL} {0}
  set_instance_parameter_value arria10_hps_0 {OVERIDE_PERI_PLL} {0}
  set_instance_parameter_value arria10_hps_0 {PERI_PLL_MANUAL_VCO_FREQ} {2000}
  set_instance_parameter_value arria10_hps_0 {CLK_MAIN_PLL_SOURCE2} {0}
  set_instance_parameter_value arria10_hps_0 {CLK_PERI_PLL_SOURCE2} {0}
  set_instance_parameter_value arria10_hps_0 {CLK_MPU_SOURCE} {0}
  set_instance_parameter_value arria10_hps_0 {CLK_MPU_CNT} {0}
  set_instance_parameter_value arria10_hps_0 {CLK_NOC_SOURCE} {0}
  set_instance_parameter_value arria10_hps_0 {CLK_NOC_CNT} {0}
  set_instance_parameter_value arria10_hps_0 {CLK_S2F_USER0_SOURCE} {0}
  set_instance_parameter_value arria10_hps_0 {CLK_S2F_USER1_SOURCE} {0}
  set_instance_parameter_value arria10_hps_0 {CLK_HMC_PLL_SOURCE} {0}
  set_instance_parameter_value arria10_hps_0 {CLK_EMAC_PTP_SOURCE} {1}
  set_instance_parameter_value arria10_hps_0 {CLK_GPIO_SOURCE} {1}
  set_instance_parameter_value arria10_hps_0 {CLK_SDMMC_SOURCE} {1}
  set_instance_parameter_value arria10_hps_0 {CLK_EMACA_SOURCE} {1}
  set_instance_parameter_value arria10_hps_0 {CLK_EMACB_SOURCE} {1}
  set_instance_parameter_value arria10_hps_0 {MAINPLLGRP_PERIPH_REF_CNT} {2048}
  set_instance_parameter_value arria10_hps_0 {H2F_PENDING_RST_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {H2F_COLD_RST_Enable} {0}
  set_instance_parameter_value arria10_hps_0 {F2H_DBG_RST_Enable} {1}
  set_instance_parameter_value arria10_hps_0 {F2H_WARM_RST_Enable} {1}
  set_instance_parameter_value arria10_hps_0 {F2H_COLD_RST_Enable} {1}
if {$hps_sdram == "D9RPL" || $hps_sdram == "D9PZN" || $hps_sdram == "D9RGX"} {
  set_instance_parameter_value arria10_hps_0 {EMIF_CONDUIT_Enable} {1}
} else {
  set_instance_parameter_value arria10_hps_0 {EMIF_CONDUIT_Enable} {0}
}
  set_instance_parameter_value arria10_hps_0 {EMAC0_PinMuxing} {IO}
  set_instance_parameter_value arria10_hps_0 {EMAC0_Mode} {RGMII_with_MDIO}
if {$hps_sgmii == 1} {
  set_instance_parameter_value arria10_hps_0 {EMAC1_PinMuxing} {FPGA}
  set_instance_parameter_value arria10_hps_0 {EMAC1_Mode} {RGMII_with_MDIO}
} else {	
  set_instance_parameter_value arria10_hps_0 {EMAC1_PinMuxing} {Unused}
  set_instance_parameter_value arria10_hps_0 {EMAC1_Mode} {N/A}
}
if {$hps_sgmii == 1 && $SGMII_COUNT == 2} {
  set_instance_parameter_value arria10_hps_0 {EMAC2_PinMuxing} {FPGA}
  set_instance_parameter_value arria10_hps_0 {EMAC2_Mode} {RGMII_with_MDIO}
} else {
  set_instance_parameter_value arria10_hps_0 {EMAC2_PinMuxing} {Unused}
  set_instance_parameter_value arria10_hps_0 {EMAC2_Mode} {N/A}
}
if {$boot_device == "NAND"} {
  set_instance_parameter_value arria10_hps_0 {NAND_PinMuxing} {IO}
  set_instance_parameter_value arria10_hps_0 {NAND_Mode} {8-bit}
} else {
  set_instance_parameter_value arria10_hps_0 {NAND_PinMuxing} {Unused}
  set_instance_parameter_value arria10_hps_0 {NAND_Mode} {N/A}
}
if {$boot_device == "QSPI"} {
  set_instance_parameter_value arria10_hps_0 {QSPI_PinMuxing} {IO}
  set_instance_parameter_value arria10_hps_0 {QSPI_Mode} {1ss}
} else {
  set_instance_parameter_value arria10_hps_0 {QSPI_PinMuxing} {Unused}
  set_instance_parameter_value arria10_hps_0 {QSPI_Mode} {N/A}
}
if {$boot_device == "SDMMC"} {
  set_instance_parameter_value arria10_hps_0 {SDMMC_PinMuxing} {IO}
  set_instance_parameter_value arria10_hps_0 {SDMMC_Mode} {8-bit}
} else {
  set_instance_parameter_value arria10_hps_0 {SDMMC_PinMuxing} {Unused}
  set_instance_parameter_value arria10_hps_0 {SDMMC_Mode} {N/A}
}
  set_instance_parameter_value arria10_hps_0 {USB0_PinMuxing} {IO}
  set_instance_parameter_value arria10_hps_0 {USB0_Mode} {default}
  set_instance_parameter_value arria10_hps_0 {USB1_PinMuxing} {Unused}
  set_instance_parameter_value arria10_hps_0 {USB1_Mode} {N/A}
  set_instance_parameter_value arria10_hps_0 {SPIM0_PinMuxing} {Unused}
  set_instance_parameter_value arria10_hps_0 {SPIM0_Mode} {N/A}
  set_instance_parameter_value arria10_hps_0 {SPIM1_PinMuxing} {IO}
  set_instance_parameter_value arria10_hps_0 {SPIM1_Mode} {Dual_slave_selects}
  set_instance_parameter_value arria10_hps_0 {SPIS0_PinMuxing} {Unused}
  set_instance_parameter_value arria10_hps_0 {SPIS0_Mode} {N/A}
  set_instance_parameter_value arria10_hps_0 {SPIS1_PinMuxing} {Unused}
  set_instance_parameter_value arria10_hps_0 {SPIS1_Mode} {N/A}
  set_instance_parameter_value arria10_hps_0 {UART0_PinMuxing} {Unused}
  set_instance_parameter_value arria10_hps_0 {UART0_Mode} {N/A}
  set_instance_parameter_value arria10_hps_0 {UART1_PinMuxing} {IO}
  set_instance_parameter_value arria10_hps_0 {UART1_Mode} {No_flow_control}
  set_instance_parameter_value arria10_hps_0 {I2C0_PinMuxing} {Unused}
  set_instance_parameter_value arria10_hps_0 {I2C0_Mode} {N/A}
if {$hps_sgmii == 1} {
  # re-route I2C1 from FPGA to IO48
  set_instance_parameter_value arria10_hps_0 {I2C1_PinMuxing} {FPGA}
} else {
  set_instance_parameter_value arria10_hps_0 {I2C1_PinMuxing} {IO}
}
  set_instance_parameter_value arria10_hps_0 {I2C1_Mode} {default}
  set_instance_parameter_value arria10_hps_0 {I2CEMAC0_PinMuxing} {Unused}
  set_instance_parameter_value arria10_hps_0 {I2CEMAC0_Mode} {N/A}
  set_instance_parameter_value arria10_hps_0 {I2CEMAC1_PinMuxing} {Unused}
  set_instance_parameter_value arria10_hps_0 {I2CEMAC1_Mode} {N/A}
  set_instance_parameter_value arria10_hps_0 {I2CEMAC2_PinMuxing} {Unused}
  set_instance_parameter_value arria10_hps_0 {I2CEMAC2_Mode} {N/A}
if {$hps_sgmii == 1 || $fast_trace == 1} {
  set_instance_parameter_value arria10_hps_0 {TRACE_PinMuxing} {FPGA}
  set_instance_parameter_value arria10_hps_0 {TRACE_Mode} {default}
} else {
  set_instance_parameter_value arria10_hps_0 {TRACE_PinMuxing} {IO}
  set_instance_parameter_value arria10_hps_0 {TRACE_Mode} {default}
}
  set_instance_parameter_value arria10_hps_0 {CM_PinMuxing} {Unused}
  set_instance_parameter_value arria10_hps_0 {CM_Mode} {N/A}
  set_instance_parameter_value arria10_hps_0 {PLL_CLK0} {Unused}
  set_instance_parameter_value arria10_hps_0 {PLL_CLK1} {Unused}
  set_instance_parameter_value arria10_hps_0 {PLL_CLK2} {Unused}
  set_instance_parameter_value arria10_hps_0 {PLL_CLK3} {Unused}
  set_instance_parameter_value arria10_hps_0 {PLL_CLK4} {Unused}
  set_instance_parameter_value arria10_hps_0 {HPS_IO_Enable} "$dedicated_io_assignment $io48_q1_assignment $io48_q2_assignment $io48_q3_assignment $io48_q4_assignment"
	
if {$hps_sdram == "D9RPL"} {
# dual rank DDR3 -1866
  add_instance emif_a10_hps_0 altera_emif_a10_hps
  set_instance_parameter_value emif_a10_hps_0 {PROTOCOL_ENUM} {PROTOCOL_DDR3}
  set_instance_parameter_value emif_a10_hps_0 {IS_ED_SLAVE} {0}
  set_instance_parameter_value emif_a10_hps_0 {INTERNAL_TESTING_MODE} {0}
 # set_instance_parameter_value emif_a10_hps_0 {SHORT_QSYS_INTERFACE_NAMES} {1}
  set_instance_parameter_value emif_a10_hps_0 {PLL_ADD_EXTRA_CLKS} {0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_USER_NUM_OF_EXTRA_CLKS} {0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_PHASE_SHIFT_UNIT_GUI_0} {0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_PHASE_SHIFT_UNIT_GUI_1} {0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_PHASE_SHIFT_UNIT_GUI_2} {0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_PHASE_SHIFT_UNIT_GUI_3} {0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_PHASE_SHIFT_UNIT_GUI_4} {0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_DESIRED_FREQ_MHZ_GUI_5} {100.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_FREQ_MHZ_GUI_5} {100.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_PHASE_SHIFT_UNIT_GUI_5} {0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_DESIRED_PHASE_GUI_5} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_PHASE_PS_GUI_5} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_PHASE_DEG_GUI_5} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_DESIRED_DUTY_CYCLE_GUI_5} {50.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_DUTY_CYCLE_GUI_5} {50.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_DESIRED_FREQ_MHZ_GUI_6} {100.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_FREQ_MHZ_GUI_6} {100.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_PHASE_SHIFT_UNIT_GUI_6} {0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_DESIRED_PHASE_GUI_6} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_PHASE_PS_GUI_6} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_PHASE_DEG_GUI_6} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_DESIRED_DUTY_CYCLE_GUI_6} {50.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_DUTY_CYCLE_GUI_6} {50.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_DESIRED_FREQ_MHZ_GUI_7} {100.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_FREQ_MHZ_GUI_7} {100.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_PHASE_SHIFT_UNIT_GUI_7} {0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_DESIRED_PHASE_GUI_7} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_PHASE_PS_GUI_7} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_PHASE_DEG_GUI_7} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_DESIRED_DUTY_CYCLE_GUI_7} {50.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_DUTY_CYCLE_GUI_7} {50.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_DESIRED_FREQ_MHZ_GUI_8} {100.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_FREQ_MHZ_GUI_8} {100.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_PHASE_SHIFT_UNIT_GUI_8} {0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_DESIRED_PHASE_GUI_8} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_PHASE_PS_GUI_8} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_PHASE_DEG_GUI_8} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_DESIRED_DUTY_CYCLE_GUI_8} {50.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_DUTY_CYCLE_GUI_8} {50.0}
  
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_CONFIG_ENUM} {CONFIG_PHY_AND_HARD_CTRL}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_USER_PING_PONG_EN} {0}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_MEM_CLK_FREQ_MHZ} {800.0}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_DEFAULT_REF_CLK_FREQ} {0}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_USER_REF_CLK_FREQ_MHZ} {133.333}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_REF_CLK_JITTER_PS} {10.0}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_RATE_ENUM} {RATE_HALF}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_CORE_CLKS_SHARING_ENUM} {CORE_CLKS_SHARING_DISABLED}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_IO_VOLTAGE} {1.5}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_DEFAULT_IO} {0}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_CAL_ADDR0} {0}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_CAL_ADDR1} {8}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_CAL_ENABLE_NON_DES} {1}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_USER_AC_IO_STD_ENUM} {IO_STD_SSTL_15_C1}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_USER_AC_MODE_ENUM} {CURRENT_ST_12}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_USER_AC_SLEW_RATE_ENUM} {SLEW_RATE_FAST}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_USER_CK_IO_STD_ENUM} {IO_STD_SSTL_15_C1}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_USER_CK_MODE_ENUM} {CURRENT_ST_12}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_USER_CK_SLEW_RATE_ENUM} {SLEW_RATE_FAST}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_USER_DATA_IO_STD_ENUM} {IO_STD_SSTL_15}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_USER_DATA_OUT_MODE_ENUM} {OUT_OCT_34_CAL}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_USER_DATA_IN_MODE_ENUM} {IN_OCT_120_CAL}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_USER_PLL_REF_CLK_IO_STD_ENUM} {IO_STD_LVDS}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_USER_RZQ_IO_STD_ENUM} {IO_STD_CMOS_15}
  
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_FORMAT_ENUM} {MEM_FORMAT_UDIMM}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_DQ_WIDTH} $hps_sdram_width
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_DQ_PER_DQS} {8}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_DISCRETE_CS_WIDTH} {1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_NUM_OF_DIMMS} {1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_RANKS_PER_DIMM} {2}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_CKE_PER_DIMM} {1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_CK_WIDTH} {1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_ROW_ADDR_WIDTH} {15}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_COL_ADDR_WIDTH} {10}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_BANK_ADDR_WIDTH} {3}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_DM_EN} {1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_MIRROR_ADDRESSING_EN} {1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_RDIMM_CONFIG} {0000000000000000}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_LRDIMM_EXTENDED_CONFIG} {000000000000000000}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_ALERT_N_PLACEMENT_ENUM} {DDR3_ALERT_N_PLACEMENT_AC_LANES}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_ALERT_N_DQS_GROUP} {0}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_BL_ENUM} {DDR3_BL_BL8}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_BT_ENUM} {DDR3_BT_SEQUENTIAL}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_ASR_ENUM} {DDR3_ASR_MANUAL}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_SRT_ENUM} {DDR3_SRT_NORMAL}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_PD_ENUM} {DDR3_PD_OFF}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_DRV_STR_ENUM} {DDR3_DRV_STR_RZQ_7}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_DLL_EN} {1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_RTT_NOM_ENUM} {DDR3_RTT_NOM_ODT_DISABLED}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_RTT_WR_ENUM} {DDR3_RTT_WR_RZQ_4}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_WTCL} {8}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_ATCL_ENUM} {DDR3_ATCL_DISABLED}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TCL} {11}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_USE_DEFAULT_ODT} {1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_R_ODTN_1X1} {Rank\ 0}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_R_ODT0_1X1} {off}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_W_ODTN_1X1} {Rank\ 0}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_W_ODT0_1X1} {on}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_R_ODTN_2X2} {Rank\ 0 Rank\ 1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_R_ODT0_2X2} {off off}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_R_ODT1_2X2} {off off}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_W_ODTN_2X2} {Rank\ 0 Rank\ 1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_W_ODT0_2X2} {on off}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_W_ODT1_2X2} {off on}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_R_ODTN_4X2} {Rank\ 0 Rank\ 1 Rank\ 2 Rank\ 3}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_R_ODT0_4X2} {off off on on}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_R_ODT1_4X2} {on on off off}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_W_ODTN_4X2} {Rank\ 0 Rank\ 1 Rank\ 2 Rank\ 3}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_W_ODT0_4X2} {off off on on}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_W_ODT1_4X2} {on on off off}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_R_ODTN_4X4} {Rank\ 0 Rank\ 1 Rank\ 2 Rank\ 3}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_R_ODT0_4X4} {off off off off}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_R_ODT1_4X4} {off off on on}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_R_ODT2_4X4} {off off off off}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_R_ODT3_4X4} {on on off off}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_W_ODTN_4X4} {Rank\ 0 Rank\ 1 Rank\ 2 Rank\ 3}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_W_ODT0_4X4} {on on off off}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_W_ODT1_4X4} {off off on on}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_W_ODT2_4X4} {off off on on}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_W_ODT3_4X4} {on on off off}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_SPEEDBIN_ENUM} {DDR3_SPEEDBIN_1866}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TIS_PS} {65}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TIS_AC_MV} {135}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TIH_PS} {100}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TIH_DC_MV} {100}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TDS_PS} {68}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TDS_AC_MV} {135}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TDH_PS} {70}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TDH_DC_MV} {100}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TDQSQ_PS} {85}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TQH_CYC} {0.38}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TDQSCK_PS} {195}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TDQSS_CYC} {0.27}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TQSH_CYC} {0.4}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TDSH_CYC} {0.18}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TWLS_PS} {140.0}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TWLH_PS} {140.0}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TDSS_CYC} {0.18}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TINIT_US} {500}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TMRD_CK_CYC} {4}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TRAS_NS} {34.0}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TRCD_NS} {13.91}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TRP_NS} {13.91}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TREFI_US} {7.8}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TRFC_NS} {350.0}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TWR_NS} {15.0}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TWTR_CYC} {6}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TFAW_NS} {30.0}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TRRD_CYC} {4}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TRTP_CYC} {6}
  
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_USE_DEFAULT_SLEW_RATES} {1}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_USE_DEFAULT_ISI_VALUES} {1}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_USER_CK_SLEW_RATE} {4.0}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_USER_AC_SLEW_RATE} {2.0}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_USER_RCLK_SLEW_RATE} {5.0}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_USER_WCLK_SLEW_RATE} {4.0}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_USER_RDATA_SLEW_RATE} {2.5}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_USER_WDATA_SLEW_RATE} {2.0}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_USER_AC_ISI_NS} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_USER_RCLK_ISI_NS} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_USER_WCLK_ISI_NS} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_USER_RDATA_ISI_NS} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_USER_WDATA_ISI_NS} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_IS_SKEW_WITHIN_DQS_DESKEWED} {0}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_BRD_SKEW_WITHIN_DQS_NS} {0.02}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_PKG_BRD_SKEW_WITHIN_DQS_NS} {0.02}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_IS_SKEW_WITHIN_AC_DESKEWED} {1}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_BRD_SKEW_WITHIN_AC_NS} {0.02}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_PKG_BRD_SKEW_WITHIN_AC_NS} {0.02}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_DQS_TO_CK_SKEW_NS} {0.02}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_SKEW_BETWEEN_DIMMS_NS} {0.05}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_SKEW_BETWEEN_DQS_NS} {0.02}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_AC_TO_CK_SKEW_NS} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_MAX_CK_DELAY_NS} {0.6}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_MAX_DQS_DELAY_NS} {0.6}
  
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_AVL_PROTOCOL_ENUM} {CTRL_AVL_PROTOCOL_ST}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_SELF_REFRESH_EN} {0}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_AUTO_POWER_DOWN_EN} {0}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_AUTO_POWER_DOWN_CYCS} {32}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_USER_REFRESH_EN} {0}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_USER_PRIORITY_EN} {0}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_AUTO_PRECHARGE_EN} {0}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_ADDR_ORDER_ENUM} {DDR3_CTRL_ADDR_ORDER_CS_R_B_C}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_ECC_EN} $hps_sdram_ecc
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_ECC_AUTO_CORRECTION_EN} {0}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_REORDER_EN} {1}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_STARVE_LIMIT} {10}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_MMR_EN} {0}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_RD_TO_WR_SAME_CHIP_DELTA_CYCS} {0}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_WR_TO_RD_SAME_CHIP_DELTA_CYCS} {0}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_RD_TO_RD_DIFF_CHIP_DELTA_CYCS} {0}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_RD_TO_WR_DIFF_CHIP_DELTA_CYCS} {0}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_WR_TO_WR_DIFF_CHIP_DELTA_CYCS} {0}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_WR_TO_RD_DIFF_CHIP_DELTA_CYCS} {0}
  
  set_instance_parameter_value emif_a10_hps_0 {DIAG_DDR3_SIM_CAL_MODE_ENUM} {SIM_CAL_MODE_SKIP}
  set_instance_parameter_value emif_a10_hps_0 {DIAG_DDR3_EXPORT_SEQ_AVALON_SLAVE} {CAL_DEBUG_EXPORT_MODE_DISABLED}
  set_instance_parameter_value emif_a10_hps_0 {DIAG_DDR3_EXPORT_SEQ_AVALON_MASTER} {0}
  set_instance_parameter_value emif_a10_hps_0 {DIAG_DDR3_EX_DESIGN_NUM_OF_SLAVES} {1}
  set_instance_parameter_value emif_a10_hps_0 {DIAG_DDR3_INTERFACE_ID} {0}
  set_instance_parameter_value emif_a10_hps_0 {DIAG_DDR3_EFFICIENCY_MONITOR} {EFFMON_MODE_DISABLED}
  set_instance_parameter_value emif_a10_hps_0 {DIAG_DDR3_USE_TG_AVL_2} {0}
  set_instance_parameter_value emif_a10_hps_0 {DIAG_DDR3_TG_DATA_PATTERN_LENGTH} {8}
  set_instance_parameter_value emif_a10_hps_0 {DIAG_DDR3_TG_BE_PATTERN_LENGTH} {8}
  set_instance_parameter_value emif_a10_hps_0 {DIAG_DDR3_CA_LEVEL_EN} {0}
  set_instance_parameter_value emif_a10_hps_0 {DIAG_ENABLE_HPS_EMIF_DEBUG} {$hps_sdram_debug_enable}
  set_instance_parameter_value emif_a10_hps_0 {DIAG_ENABLE_JTAG_UART_HEX} {$hps_sdram_debug_enable}

} elseif {$hps_sdram == "D9PZN"} { 
# single rank DDR3 -2133
  add_instance emif_a10_hps_0 altera_emif_a10_hps
  set_instance_parameter_value emif_a10_hps_0 {PROTOCOL_ENUM} {PROTOCOL_DDR3}
  set_instance_parameter_value emif_a10_hps_0 {IS_ED_SLAVE} {0}
  set_instance_parameter_value emif_a10_hps_0 {INTERNAL_TESTING_MODE} {0}
  #set_instance_parameter_value emif_a10_hps_0 {SHORT_QSYS_INTERFACE_NAMES} {1}
  set_instance_parameter_value emif_a10_hps_0 {PLL_ADD_EXTRA_CLKS} {0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_USER_NUM_OF_EXTRA_CLKS} {0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_PHASE_SHIFT_UNIT_GUI_0} {0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_PHASE_SHIFT_UNIT_GUI_1} {0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_PHASE_SHIFT_UNIT_GUI_2} {0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_PHASE_SHIFT_UNIT_GUI_3} {0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_PHASE_SHIFT_UNIT_GUI_4} {0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_DESIRED_FREQ_MHZ_GUI_5} {100.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_FREQ_MHZ_GUI_5} {100.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_PHASE_SHIFT_UNIT_GUI_5} {0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_DESIRED_PHASE_GUI_5} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_PHASE_PS_GUI_5} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_PHASE_DEG_GUI_5} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_DESIRED_DUTY_CYCLE_GUI_5} {50.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_DUTY_CYCLE_GUI_5} {50.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_DESIRED_FREQ_MHZ_GUI_6} {100.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_FREQ_MHZ_GUI_6} {100.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_PHASE_SHIFT_UNIT_GUI_6} {0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_DESIRED_PHASE_GUI_6} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_PHASE_PS_GUI_6} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_PHASE_DEG_GUI_6} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_DESIRED_DUTY_CYCLE_GUI_6} {50.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_DUTY_CYCLE_GUI_6} {50.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_DESIRED_FREQ_MHZ_GUI_7} {100.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_FREQ_MHZ_GUI_7} {100.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_PHASE_SHIFT_UNIT_GUI_7} {0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_DESIRED_PHASE_GUI_7} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_PHASE_PS_GUI_7} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_PHASE_DEG_GUI_7} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_DESIRED_DUTY_CYCLE_GUI_7} {50.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_DUTY_CYCLE_GUI_7} {50.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_DESIRED_FREQ_MHZ_GUI_8} {100.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_FREQ_MHZ_GUI_8} {100.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_PHASE_SHIFT_UNIT_GUI_8} {0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_DESIRED_PHASE_GUI_8} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_PHASE_PS_GUI_8} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_PHASE_DEG_GUI_8} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_DESIRED_DUTY_CYCLE_GUI_8} {50.0}
  set_instance_parameter_value emif_a10_hps_0 {PLL_EXTRA_CLK_ACTUAL_DUTY_CYCLE_GUI_8} {50.0}
	
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_CONFIG_ENUM} {CONFIG_PHY_AND_HARD_CTRL}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_USER_PING_PONG_EN} {0}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_MEM_CLK_FREQ_MHZ} {1066.667}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_DEFAULT_REF_CLK_FREQ} {0}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_USER_REF_CLK_FREQ_MHZ} {133.333}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_REF_CLK_JITTER_PS} {10.0}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_RATE_ENUM} {RATE_HALF}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_CORE_CLKS_SHARING_ENUM} {CORE_CLKS_SHARING_DISABLED}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_IO_VOLTAGE} {1.5}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_DEFAULT_IO} {0}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_CAL_ADDR0} {0}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_CAL_ADDR1} {8}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_CAL_ENABLE_NON_DES} {1}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_USER_AC_IO_STD_ENUM} {IO_STD_SSTL_15_C1}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_USER_AC_MODE_ENUM} {CURRENT_ST_12}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_USER_AC_SLEW_RATE_ENUM} {SLEW_RATE_FAST}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_USER_CK_IO_STD_ENUM} {IO_STD_SSTL_15_C1}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_USER_CK_MODE_ENUM} {CURRENT_ST_12}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_USER_CK_SLEW_RATE_ENUM} {SLEW_RATE_FAST}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_USER_DATA_IO_STD_ENUM} {IO_STD_SSTL_15}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_USER_DATA_OUT_MODE_ENUM} {OUT_OCT_34_CAL}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_USER_DATA_IN_MODE_ENUM} {IN_OCT_120_CAL}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_USER_PLL_REF_CLK_IO_STD_ENUM} {IO_STD_LVDS}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR3_USER_RZQ_IO_STD_ENUM} {IO_STD_CMOS_15}
  
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_FORMAT_ENUM} {MEM_FORMAT_UDIMM}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_DQ_WIDTH} $hps_sdram_width
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_DQ_PER_DQS} {8}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_DISCRETE_CS_WIDTH} {1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_NUM_OF_DIMMS} {1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_RANKS_PER_DIMM} {1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_CKE_PER_DIMM} {1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_CK_WIDTH} {1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_ROW_ADDR_WIDTH} {15}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_COL_ADDR_WIDTH} {10}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_BANK_ADDR_WIDTH} {3}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_DM_EN} {1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_MIRROR_ADDRESSING_EN} {1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_RDIMM_CONFIG} {0}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_LRDIMM_EXTENDED_CONFIG} {0x0}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_ALERT_N_PLACEMENT_ENUM} {DDR3_ALERT_N_PLACEMENT_AC_LANES}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_ALERT_N_DQS_GROUP} {0}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_BL_ENUM} {DDR3_BL_BL8}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_BT_ENUM} {DDR3_BT_SEQUENTIAL}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_ASR_ENUM} {DDR3_ASR_MANUAL}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_SRT_ENUM} {DDR3_SRT_NORMAL}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_PD_ENUM} {DDR3_PD_OFF}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_DRV_STR_ENUM} {DDR3_DRV_STR_RZQ_7}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_DLL_EN} {1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_RTT_NOM_ENUM} {DDR3_RTT_NOM_ODT_DISABLED}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_RTT_WR_ENUM} {DDR3_RTT_WR_RZQ_4}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_WTCL} {10}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_ATCL_ENUM} {DDR3_ATCL_DISABLED}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TCL} {14}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_USE_DEFAULT_ODT} {1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_R_ODTN_1X1} {Rank\ 0}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_R_ODT0_1X1} {off}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_W_ODTN_1X1} {Rank\ 0}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_W_ODT0_1X1} {on}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_R_ODTN_2X2} {Rank\ 0 Rank\ 1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_R_ODT0_2X2} {off off}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_R_ODT1_2X2} {off off}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_W_ODTN_2X2} {Rank\ 0 Rank\ 1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_W_ODT0_2X2} {on off}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_W_ODT1_2X2} {off on}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_R_ODTN_4X2} {Rank\ 0 Rank\ 1 Rank\ 2 Rank\ 3}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_R_ODT0_4X2} {off off on on}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_R_ODT1_4X2} {on on off off}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_W_ODTN_4X2} {Rank\ 0 Rank\ 1 Rank\ 2 Rank\ 3}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_W_ODT0_4X2} {off off on on}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_W_ODT1_4X2} {on on off off}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_R_ODTN_4X4} {Rank\ 0 Rank\ 1 Rank\ 2 Rank\ 3}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_R_ODT0_4X4} {off off off off}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_R_ODT1_4X4} {off off on on}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_R_ODT2_4X4} {off off off off}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_R_ODT3_4X4} {on on off off}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_W_ODTN_4X4} {Rank\ 0 Rank\ 1 Rank\ 2 Rank\ 3}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_W_ODT0_4X4} {on on off off}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_W_ODT1_4X4} {off off on on}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_W_ODT2_4X4} {off off on on}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_W_ODT3_4X4} {on on off off}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_SPEEDBIN_ENUM} {DDR3_SPEEDBIN_2133}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TIS_PS} {60}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TIS_AC_MV} {135}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TIH_PS} {95}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TIH_DC_MV} {100}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TDS_PS} {53}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TDS_AC_MV} {135}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TDH_PS} {55}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TDH_DC_MV} {100}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TDQSQ_PS} {75}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TQH_CYC} {0.38}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TDQSCK_PS} {180}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TDQSS_CYC} {0.27}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TQSH_CYC} {0.4}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TDSH_CYC} {0.18}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TWLS_PS} {125.0}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TWLH_PS} {125.0}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TDSS_CYC} {0.18}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TINIT_US} {500}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TMRD_CK_CYC} {4}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TRAS_NS} {33.0}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TRCD_NS} {13.13}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TRP_NS} {13.13}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TREFI_US} {7.8}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TRFC_NS} {260.0}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TWR_NS} {15.0}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TWTR_CYC} {8}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TFAW_NS} {35.0}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TRRD_CYC} {6}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR3_TRTP_CYC} {8}
  
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_USE_DEFAULT_SLEW_RATES} {1}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_USE_DEFAULT_ISI_VALUES} {1}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_USER_CK_SLEW_RATE} {4.0}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_USER_AC_SLEW_RATE} {2.0}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_USER_RCLK_SLEW_RATE} {5.0}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_USER_WCLK_SLEW_RATE} {4.0}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_USER_RDATA_SLEW_RATE} {2.5}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_USER_WDATA_SLEW_RATE} {2.0}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_USER_AC_ISI_NS} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_USER_RCLK_ISI_NS} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_USER_WCLK_ISI_NS} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_USER_RDATA_ISI_NS} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_USER_WDATA_ISI_NS} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_IS_SKEW_WITHIN_DQS_DESKEWED} {0}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_BRD_SKEW_WITHIN_DQS_NS} {0.02}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_PKG_BRD_SKEW_WITHIN_DQS_NS} {0.02}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_IS_SKEW_WITHIN_AC_DESKEWED} {1}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_BRD_SKEW_WITHIN_AC_NS} {0.02}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_PKG_BRD_SKEW_WITHIN_AC_NS} {0.02}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_DQS_TO_CK_SKEW_NS} {0.02}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_SKEW_BETWEEN_DIMMS_NS} {0.05}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_SKEW_BETWEEN_DQS_NS} {0.02}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_AC_TO_CK_SKEW_NS} {0.0}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_MAX_CK_DELAY_NS} {0.6}
  set_instance_parameter_value emif_a10_hps_0 {BOARD_DDR3_MAX_DQS_DELAY_NS} {0.6}
  
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_AVL_PROTOCOL_ENUM} {CTRL_AVL_PROTOCOL_ST}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_SELF_REFRESH_EN} {0}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_AUTO_POWER_DOWN_EN} {0}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_AUTO_POWER_DOWN_CYCS} {32}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_USER_REFRESH_EN} {0}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_USER_PRIORITY_EN} {0}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_AUTO_PRECHARGE_EN} {0}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_ADDR_ORDER_ENUM} {DDR3_CTRL_ADDR_ORDER_CS_R_B_C}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_ECC_EN} $hps_sdram_ecc
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_ECC_AUTO_CORRECTION_EN} {0}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_REORDER_EN} {1}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_STARVE_LIMIT} {10}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_MMR_EN} {0}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_RD_TO_WR_SAME_CHIP_DELTA_CYCS} {0}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_WR_TO_RD_SAME_CHIP_DELTA_CYCS} {0}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_RD_TO_RD_DIFF_CHIP_DELTA_CYCS} {0}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_RD_TO_WR_DIFF_CHIP_DELTA_CYCS} {0}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_WR_TO_WR_DIFF_CHIP_DELTA_CYCS} {0}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR3_WR_TO_RD_DIFF_CHIP_DELTA_CYCS} {0}
  
  set_instance_parameter_value emif_a10_hps_0 {DIAG_DDR3_SIM_CAL_MODE_ENUM} {SIM_CAL_MODE_SKIP}
  set_instance_parameter_value emif_a10_hps_0 {DIAG_DDR3_EXPORT_SEQ_AVALON_SLAVE} {CAL_DEBUG_EXPORT_MODE_DISABLED}
  set_instance_parameter_value emif_a10_hps_0 {DIAG_DDR3_EXPORT_SEQ_AVALON_MASTER} {0}
  set_instance_parameter_value emif_a10_hps_0 {DIAG_DDR3_EX_DESIGN_NUM_OF_SLAVES} {1}
  set_instance_parameter_value emif_a10_hps_0 {DIAG_DDR3_INTERFACE_ID} {0}
  set_instance_parameter_value emif_a10_hps_0 {DIAG_DDR3_EFFICIENCY_MONITOR} {EFFMON_MODE_DISABLED}
  set_instance_parameter_value emif_a10_hps_0 {DIAG_DDR3_USE_TG_AVL_2} {0}
  set_instance_parameter_value emif_a10_hps_0 {DIAG_DDR3_TG_DATA_PATTERN_LENGTH} {8}
  set_instance_parameter_value emif_a10_hps_0 {DIAG_DDR3_TG_BE_PATTERN_LENGTH} {8}
  set_instance_parameter_value emif_a10_hps_0 {DIAG_DDR3_CA_LEVEL_EN} {0}
  set_instance_parameter_value emif_a10_hps_0 {DIAG_ENABLE_HPS_EMIF_DEBUG} {$hps_sdram_debug_enable}
  set_instance_parameter_value emif_a10_hps_0 {DIAG_ENABLE_JTAG_UART_HEX} {$hps_sdram_debug_enable}
  
} elseif {$hps_sdram == "D9RGX"} {
# DDR4 single rank -2133
  add_instance emif_a10_hps_0 altera_emif_a10_hps
  set_validation_property AUTOMATIC_VALIDATION false
  #set_instance_parameter_value emif_a10_hps_0 {SHORT_QSYS_INTERFACE_NAMES} {1}
  set_instance_parameter_value emif_a10_hps_0 {PROTOCOL_ENUM} {PROTOCOL_DDR4}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR4_RATE_ENUM} {RATE_HALF}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_FORMAT_ENUM} {MEM_FORMAT_UDIMM}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_DQ_WIDTH} $hps_sdram_width
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TCL} {20}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_WTCL} {18}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_ALERT_N_PLACEMENT_ENUM} {DDR4_ALERT_N_PLACEMENT_DATA_LANES}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_ALERT_N_DQS_GROUP} {3}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_ALERT_PAR_EN} {1}
  set_instance_parameter_value emif_a10_hps_0 {DIAG_ENABLE_HPS_EMIF_DEBUG} {$hps_sdram_debug_enable}
  set_instance_parameter_value emif_a10_hps_0 {DIAG_ENABLE_JTAG_UART_HEX} {$hps_sdram_debug_enable}
  set_instance_parameter_value emif_a10_hps_0 {DIAG_DDR4_SKIP_CA_LEVEL} {1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_NUM_OF_DIMMS} {1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_RANKS_PER_DIMM} {1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_CK_WIDTH} {1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_READ_PREAMBLE} {2}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_WRITE_PREAMBLE} {1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_RTT_WR_ENUM} {DDR4_RTT_WR_ODT_DISABLED}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_DRV_STR_ENUM} {DDR4_DRV_STR_RZQ_7}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_RTT_NOM_ENUM} {DDR4_RTT_NOM_RZQ_6}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_DM_EN} {1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_READ_DBI} {1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_WRITE_DBI} {0}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR4_CONFIG_ENUM} {CONFIG_PHY_AND_HARD_CTRL}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR4_USER_REF_CLK_FREQ_MHZ} {133.333}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR4_DEFAULT_REF_CLK_FREQ} {0}
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR4_ECC_EN} $hps_sdram_ecc
  set_instance_parameter_value emif_a10_hps_0 {CTRL_DDR4_ECC_AUTO_CORRECTION_EN} {0}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR4_DEFAULT_IO} {0}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR4_USER_AC_IO_STD_ENUM} {IO_STD_SSTL_12}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR4_USER_CK_IO_STD_ENUM} {IO_STD_SSTL_12}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR4_USER_DATA_IO_STD_ENUM} {IO_STD_POD_12}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR4_USER_AC_MODE_ENUM} {OUT_OCT_40_CAL}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR4_USER_CK_MODE_ENUM} {OUT_OCT_40_CAL}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR4_USER_DATA_OUT_MODE_ENUM} {OUT_OCT_34_CAL}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR4_USER_DATA_IN_MODE_ENUM} {IN_OCT_60_CAL}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR4_USER_PLL_REF_CLK_IO_STD_ENUM} {IO_STD_LVDS}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR4_USER_RZQ_IO_STD_ENUM} {IO_STD_CMOS_12}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR4_MEM_CLK_FREQ_MHZ} {1066.667}
  
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_SPEEDBIN_ENUM} {DDR4_SPEEDBIN_2666}
  set_instance_parameter_value emif_a10_hps_0 {PHY_DDR4_IO_VOLTAGE} {1.2}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_DISCRETE_CS_WIDTH} {1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_DQ_PER_DQS} {8}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_BANK_ADDR_WIDTH} {2}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_BANK_GROUP_WIDTH} {1}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_COL_ADDR_WIDTH} {10}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_ROW_ADDR_WIDTH} {15}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TIH_PS} {95}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TIH_DC_MV} {75}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TIS_PS} {60}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TIS_AC_MV} {100}
  ### 3 settings for 15.1 and beyond
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TDIVW_TOTAL_UI} {0.2}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TDQSQ_UI} {0.16}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TQH_UI} {0.76}
  ### 3 setting for 15.0
  # set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TDIVW_DJ_CYC} {0.1}
  # set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TDQSQ_PS} {66}
  # set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TQH_CYC} {0.38}
  #---------------------------
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_VDIVW_TOTAL} {136}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TQSH_CYC} {0.38}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TDQSCK_PS} {165}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TDQSS_CYC} {0.27}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TDSH_CYC} {0.18}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TDSS_CYC} {0.18}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TWLS_PS} {108.0}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TWLH_PS} {108.0}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TINIT_US} {500}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TMRD_CK_CYC} {8}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TRAS_NS} {32.0}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TRCD_NS} {14.25}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TRP_NS} {14.25}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TREFI_US} {7.8}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TRFC_NS} {260.0}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TWR_NS} {15.0}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TWTR_L_CYC} {10}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TWTR_S_CYC} {4}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TFAW_NS} {30.0}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TRRD_L_CYC} {8}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TRRD_S_CYC} {7}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TCCD_L_CYC} {6}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_TCCD_S_CYC} {4}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_RDIMM_CONFIG} {0}
  set_instance_parameter_value emif_a10_hps_0 {MEM_DDR4_LRDIMM_EXTENDED_CONFIG} {0x0}
  
  set_validation_property AUTOMATIC_VALIDATION true
  
} else {
    # No valid SDRAM device selected
}

if {$fast_trace == 1} {
  add_instance trace_wrapper_0 altera_trace_wrapper 
  set_instance_parameter_value trace_wrapper_0 {IN_DWIDTH} {32}
  set_instance_parameter_value trace_wrapper_0 {NUM_PIPELINE_REG} {1}
}

  add_instance fpga_only_master altera_jtag_avalon_master
  set_instance_parameter_value fpga_only_master {USE_PLI} {0}
  set_instance_parameter_value fpga_only_master {PLI_PORT} {50000}
  set_instance_parameter_value fpga_only_master {FAST_VER} {0}
  set_instance_parameter_value fpga_only_master {FIFO_DEPTHS} {2}
  
  add_instance hps_only_master altera_jtag_avalon_master
  set_instance_parameter_value hps_only_master {USE_PLI} {0}
  set_instance_parameter_value hps_only_master {PLI_PORT} {50000}
  set_instance_parameter_value hps_only_master {FAST_VER} {0}
  set_instance_parameter_value hps_only_master {FIFO_DEPTHS} {2}
  
  add_instance onchip_memory2_0 altera_avalon_onchip_memory2
  set_instance_parameter_value onchip_memory2_0 {allowInSystemMemoryContentEditor} {0}
  set_instance_parameter_value onchip_memory2_0 {blockType} {AUTO}
  set_instance_parameter_value onchip_memory2_0 {dataWidth} {64}
  set_instance_parameter_value onchip_memory2_0 {dualPort} {0}
  set_instance_parameter_value onchip_memory2_0 {initMemContent} {1}
  set_instance_parameter_value onchip_memory2_0 {initializationFileName} {onchip_mem.hex}
  set_instance_parameter_value onchip_memory2_0 {instanceID} {NONE}
  set_instance_parameter_value onchip_memory2_0 {memorySize} {262144.0}
  set_instance_parameter_value onchip_memory2_0 {readDuringWriteMode} {DONT_CARE}
  set_instance_parameter_value onchip_memory2_0 {simAllowMRAMContentsFile} {0}
  set_instance_parameter_value onchip_memory2_0 {simMemInitOnlyFilename} {0}
  set_instance_parameter_value onchip_memory2_0 {singleClockOperation} {0}
  set_instance_parameter_value onchip_memory2_0 {slave1Latency} {1}
  set_instance_parameter_value onchip_memory2_0 {slave2Latency} {1}
  set_instance_parameter_value onchip_memory2_0 {useNonDefaultInitFile} {0}
  set_instance_parameter_value onchip_memory2_0 {copyInitFile} {0}
  set_instance_parameter_value onchip_memory2_0 {useShallowMemBlocks} {0}
  set_instance_parameter_value onchip_memory2_0 {writable} {1}
  set_instance_parameter_value onchip_memory2_0 {ecc_enabled} {0}
  set_instance_parameter_value onchip_memory2_0 {resetrequest_enabled} {1}
    
  add_instance pb_lwh2f altera_avalon_mm_bridge
  set_instance_parameter_value pb_lwh2f {DATA_WIDTH} {32}
  set_instance_parameter_value pb_lwh2f {SYMBOL_WIDTH} {8}
  set_instance_parameter_value pb_lwh2f {ADDRESS_WIDTH} {20}
  set_instance_parameter_value pb_lwh2f {USE_AUTO_ADDRESS_WIDTH} {0}
  set_instance_parameter_value pb_lwh2f {ADDRESS_UNITS} {SYMBOLS}
  set_instance_parameter_value pb_lwh2f {MAX_BURST_SIZE} {1}
  set_instance_parameter_value pb_lwh2f {MAX_PENDING_RESPONSES} {1}
  set_instance_parameter_value pb_lwh2f {LINEWRAPBURSTS} {0}
  set_instance_parameter_value pb_lwh2f {PIPELINE_COMMAND} {1}
  set_instance_parameter_value pb_lwh2f {PIPELINE_RESPONSE} {1}
  
  add_instance sysid_qsys_0 altera_avalon_sysid_qsys
  set_instance_parameter_value sysid_qsys_0 {id} $SYSID
  
  add_instance led_pio altera_avalon_pio
  set_instance_parameter_value led_pio {bitClearingEdgeCapReg} {0}
  set_instance_parameter_value led_pio {bitModifyingOutReg} {0}
  set_instance_parameter_value led_pio {captureEdge} {0}
  set_instance_parameter_value led_pio {direction} {InOut}
  set_instance_parameter_value led_pio {edgeType} {RISING}
  set_instance_parameter_value led_pio {generateIRQ} {0}
  set_instance_parameter_value led_pio {irqType} {LEVEL}
  set_instance_parameter_value led_pio {resetValue} {0.0}
  set_instance_parameter_value led_pio {simDoTestBenchWiring} {0}
  set_instance_parameter_value led_pio {simDrivenValue} {0.0}
  set_instance_parameter_value led_pio {width} {4}
  
  add_instance button_pio altera_avalon_pio
  set_instance_parameter_value button_pio {bitClearingEdgeCapReg} {1}
  set_instance_parameter_value button_pio {bitModifyingOutReg} {0}
  set_instance_parameter_value button_pio {captureEdge} {1}
  set_instance_parameter_value button_pio {direction} {Input}
  set_instance_parameter_value button_pio {edgeType} {FALLING}
  set_instance_parameter_value button_pio {generateIRQ} {1}
  set_instance_parameter_value button_pio {irqType} {EDGE}
  set_instance_parameter_value button_pio {resetValue} {0.0}
  set_instance_parameter_value button_pio {simDoTestBenchWiring} {0}
  set_instance_parameter_value button_pio {simDrivenValue} {0.0}
  set_instance_parameter_value button_pio {width} {4}
  
  add_instance dipsw_pio altera_avalon_pio 
  set_instance_parameter_value dipsw_pio {bitClearingEdgeCapReg} {1}
  set_instance_parameter_value dipsw_pio {bitModifyingOutReg} {0}
  set_instance_parameter_value dipsw_pio {captureEdge} {1}
  set_instance_parameter_value dipsw_pio {direction} {Input}
  set_instance_parameter_value dipsw_pio {edgeType} {ANY}
  set_instance_parameter_value dipsw_pio {generateIRQ} {1}
  set_instance_parameter_value dipsw_pio {irqType} {EDGE}
  set_instance_parameter_value dipsw_pio {resetValue} {0.0}
  set_instance_parameter_value dipsw_pio {simDoTestBenchWiring} {0}
  set_instance_parameter_value dipsw_pio {simDrivenValue} {0.0}
  set_instance_parameter_value dipsw_pio {width} {4}
  
  add_instance ILC interrupt_latency_counter 
  set_instance_parameter_value ILC {INTR_TYPE} {0}
  set_instance_parameter_value ILC {IRQ_PORT_CNT} {2}

if {$hps_sgmii == 1} {
  for {set x 1} {$x<=$SGMII_COUNT} {incr x} {
  add_instance sgmii_$x subsys_sgmii
  ### If we want to support user specific subsystem name then subsystem name needed while sourcing the construct_*, and matching
  #add_instance sgmii_$x $sgmii_sub_system_name
  }
  if {$SGMII_COUNT > 1} {
  add_instance clock_bridge_0 altera_clock_bridge 
  set_instance_parameter_value clock_bridge_0 {EXPLICIT_CLOCK_RATE} {125000000.0}
  set_instance_parameter_value clock_bridge_0 {NUM_CLOCK_OUTPUTS} {1}
  }
}

if {$fpga_dp == 1} {
    add_instance display_port subsys_dp
    ### If we want to support user specific subsystem name then subsystem name needed while sourcing the construct_*, and matching
    #add_instance display_port $displayport_sub_system_name
}

if {$fpga_pcie == 1} {
    add_instance pcie_0 subsys_pcie
}	
  # connections and connection parameters
if {$hps_sgmii == 1} {
  for {set x 1} {$x<=$SGMII_COUNT} {incr x} {
  add_connection clk_0.clk sgmii_${x}.clk clock
  add_connection clk_0.clk_reset sgmii_${x}.reset reset
  add_connection arria10_hps_0.h2f_reset sgmii_${x}.reset reset
  
  # add_connection arria10_hps_0.emac${x} sgmii_${x}.emac conduit
  # set_connection_parameter_value arria10_hps_0.emac${x}/sgmii_${x}.emac endPort {}
  # set_connection_parameter_value arria10_hps_0.emac${x}/sgmii_${x}.emac endPortLSB {0}
  # set_connection_parameter_value arria10_hps_0.emac${x}/sgmii_${x}.emac startPort {}
  # set_connection_parameter_value arria10_hps_0.emac${x}/sgmii_${x}.emac startPortLSB {0}
  # set_connection_parameter_value arria10_hps_0.emac${x}/sgmii_${x}.emac width {0}
  
  add_connection sgmii_${x}.emac_tx_clk_in arria10_hps_0.emac${x}_tx_clk_in clock
  add_connection sgmii_${x}.emac_rx_clk_in arria10_hps_0.emac${x}_rx_clk_in clock
  add_connection arria10_hps_0.emac${x}_gtx_clk sgmii_${x}.emac_gtx_clk clock
  add_connection arria10_hps_0.emac${x}_rx_reset sgmii_${x}.emac_rx_reset reset
  add_connection arria10_hps_0.emac${x}_tx_reset sgmii_${x}.emac_tx_reset reset
  
  add_connection pb_lwh2f.m0 sgmii_${x}.gmii_to_sgmii_adapter_avalon_slave avalon
  set_connection_parameter_value pb_lwh2f.m0/sgmii_${x}.gmii_to_sgmii_adapter_avalon_slave arbitrationPriority {1}
  set_connection_parameter_value pb_lwh2f.m0/sgmii_${x}.gmii_to_sgmii_adapter_avalon_slave baseAddress [expr [expr $x* 0x0200] + 0x40]
  set_connection_parameter_value pb_lwh2f.m0/sgmii_${x}.gmii_to_sgmii_adapter_avalon_slave defaultConnection {0}
  
  add_connection pb_lwh2f.m0 sgmii_${x}.pcs_control_port avalon
  set_connection_parameter_value pb_lwh2f.m0/sgmii_${x}.pcs_control_port arbitrationPriority {1}
  set_connection_parameter_value pb_lwh2f.m0/sgmii_${x}.pcs_control_port baseAddress [expr $x* 0x0200]
  set_connection_parameter_value pb_lwh2f.m0/sgmii_${x}.pcs_control_port defaultConnection {0}
  }
}

if {$fpga_dp == 1} {
  if {$frame_reader == 1} {
    add_connection display_port.alt_vip_vfr_0_avalon_master arria10_hps_0.f2h_axi_slave avalon
    set_connection_parameter_value display_port.alt_vip_vfr_0_avalon_master/arria10_hps_0.f2h_axi_slave arbitrationPriority {1}
    set_connection_parameter_value display_port.alt_vip_vfr_0_avalon_master/arria10_hps_0.f2h_axi_slave baseAddress {0x0000}
    set_connection_parameter_value display_port.alt_vip_vfr_0_avalon_master/arria10_hps_0.f2h_axi_slave defaultConnection {0}
	
    add_connection pb_lwh2f.m0 display_port.alt_vip_vfr_0_avalon_slave avalon
    set_connection_parameter_value pb_lwh2f.m0/display_port.alt_vip_vfr_0_avalon_slave arbitrationPriority {1}
    set_connection_parameter_value pb_lwh2f.m0/display_port.alt_vip_vfr_0_avalon_slave baseAddress {0x00048000}
    set_connection_parameter_value pb_lwh2f.m0/display_port.alt_vip_vfr_0_avalon_slave defaultConnection {0}
    	
	add_connection fpga_only_master.master display_port.alt_vip_vfr_0_avalon_slave avalon
	set_connection_parameter_value fpga_only_master.master/display_port.alt_vip_vfr_0_avalon_slave arbitrationPriority {1}
	set_connection_parameter_value fpga_only_master.master/display_port.alt_vip_vfr_0_avalon_slave baseAddress {0x00048000}
	set_connection_parameter_value fpga_only_master.master/display_port.alt_vip_vfr_0_avalon_slave defaultConnection {0}
	
    add_connection arria10_hps_0.f2h_irq0 display_port.alt_vip_vfr_0_interrupt_sender interrupt
    set_connection_parameter_value arria10_hps_0.f2h_irq0/display_port.alt_vip_vfr_0_interrupt_sender irqNumber {2}	
	}
	
	add_connection clk_0.clk display_port.clk_100 clock

	add_connection clock_bridge_0.out_clk display_port.clk_vip_160 clock
	
    add_connection clk_0.clk_reset display_port.resetn reset
	
	add_connection arria10_hps_0.h2f_reset display_port.resetn reset

}

if {$fpga_pcie == 1} {
    add_connection pcie_0.address_span_extender_0_expanded_master arria10_hps_0.f2sdram1_data avalon
    set_connection_parameter_value pcie_0.address_span_extender_0_expanded_master/arria10_hps_0.f2sdram1_data arbitrationPriority {1}
    set_connection_parameter_value pcie_0.address_span_extender_0_expanded_master/arria10_hps_0.f2sdram1_data baseAddress {0x0000}
    set_connection_parameter_value pcie_0.address_span_extender_0_expanded_master/arria10_hps_0.f2sdram1_data defaultConnection {0}

    add_connection arria10_hps_0.h2f_axi_master pcie_0.ccb_h2f_100_250_s0 avalon
    set_connection_parameter_value arria10_hps_0.h2f_axi_master/pcie_0.ccb_h2f_100_250_s0 arbitrationPriority {1}
    set_connection_parameter_value arria10_hps_0.h2f_axi_master/pcie_0.ccb_h2f_100_250_s0 baseAddress {0x10000000}
    set_connection_parameter_value arria10_hps_0.h2f_axi_master/pcie_0.ccb_h2f_100_250_s0 defaultConnection {0}

    add_connection pb_lwh2f.m0 pcie_0.msgdma_0_csr avalon
    set_connection_parameter_value pb_lwh2f.m0/pcie_0.msgdma_0_csr arbitrationPriority {1}
    set_connection_parameter_value pb_lwh2f.m0/pcie_0.msgdma_0_csr baseAddress {0x00044020}
    set_connection_parameter_value pb_lwh2f.m0/pcie_0.msgdma_0_csr defaultConnection {0}

    add_connection pb_lwh2f.m0 pcie_0.msgdma_0_descriptor_slave avalon
    set_connection_parameter_value pb_lwh2f.m0/pcie_0.msgdma_0_descriptor_slave arbitrationPriority {1}
    set_connection_parameter_value pb_lwh2f.m0/pcie_0.msgdma_0_descriptor_slave baseAddress {0x00044050}
    set_connection_parameter_value pb_lwh2f.m0/pcie_0.msgdma_0_descriptor_slave defaultConnection {0}

    add_connection pb_lwh2f.m0 pcie_0.msi_to_gic_gen_0_csr avalon
    set_connection_parameter_value pb_lwh2f.m0/pcie_0.msi_to_gic_gen_0_csr arbitrationPriority {1}
    set_connection_parameter_value pb_lwh2f.m0/pcie_0.msi_to_gic_gen_0_csr baseAddress {0x00044040}
    set_connection_parameter_value pb_lwh2f.m0/pcie_0.msi_to_gic_gen_0_csr defaultConnection {0}

    add_connection pb_lwh2f.m0 pcie_0.pb_2_msi_s0 avalon
    set_connection_parameter_value pb_lwh2f.m0/pcie_0.pb_2_msi_s0 arbitrationPriority {1}
    set_connection_parameter_value pb_lwh2f.m0/pcie_0.pb_2_msi_s0 baseAddress {0x00044080}
    set_connection_parameter_value pb_lwh2f.m0/pcie_0.pb_2_msi_s0 defaultConnection {0}

    add_connection pb_lwh2f.m0 pcie_0.pcie_a10_hip_avmm_cra avalon
    set_connection_parameter_value pb_lwh2f.m0/pcie_0.pcie_a10_hip_avmm_cra arbitrationPriority {1}
    set_connection_parameter_value pb_lwh2f.m0/pcie_0.pcie_a10_hip_avmm_cra baseAddress {0x00040000}
    set_connection_parameter_value pb_lwh2f.m0/pcie_0.pcie_a10_hip_avmm_cra defaultConnection {0}

    add_connection pb_lwh2f.m0 pcie_0.performance_counter_0_control_slave avalon
    set_connection_parameter_value pb_lwh2f.m0/pcie_0.performance_counter_0_control_slave arbitrationPriority {1}
    set_connection_parameter_value pb_lwh2f.m0/pcie_0.performance_counter_0_control_slave baseAddress {0x00044000}
    set_connection_parameter_value pb_lwh2f.m0/pcie_0.performance_counter_0_control_slave defaultConnection {0}

    add_connection pb_lwh2f.m0 pio_rp_reset.s1 avalon
    set_connection_parameter_value pb_lwh2f.m0/pio_rp_reset.s1 arbitrationPriority {1}
    set_connection_parameter_value pb_lwh2f.m0/pio_rp_reset.s1 baseAddress {0x00048080}
    set_connection_parameter_value pb_lwh2f.m0/pio_rp_reset.s1 defaultConnection {0}
	
    add_connection pcie_0.pb_msgdma_read_master_m0 pcie_0.address_span_extender_0_windowed_slave avalon
    set_connection_parameter_value pcie_0.pb_msgdma_read_master_m0/pcie_0.address_span_extender_0_windowed_slave arbitrationPriority {1}
    set_connection_parameter_value pcie_0.pb_msgdma_read_master_m0/pcie_0.address_span_extender_0_windowed_slave baseAddress {0x0000}
    set_connection_parameter_value pcie_0.pb_msgdma_read_master_m0/pcie_0.address_span_extender_0_windowed_slave defaultConnection {0}

    add_connection pcie_0.pb_msgdma_write_master_m0 pcie_0.address_span_extender_0_windowed_slave avalon
    set_connection_parameter_value pcie_0.pb_msgdma_write_master_m0/pcie_0.address_span_extender_0_windowed_slave arbitrationPriority {1}
    set_connection_parameter_value pcie_0.pb_msgdma_write_master_m0/pcie_0.address_span_extender_0_windowed_slave baseAddress {0x0000}
    set_connection_parameter_value pcie_0.pb_msgdma_write_master_m0/pcie_0.address_span_extender_0_windowed_slave defaultConnection {0}

    add_connection pcie_0.pb_pcie_rxm_m0 pcie_0.address_span_extender_0_windowed_slave avalon
    set_connection_parameter_value pcie_0.pb_pcie_rxm_m0/pcie_0.address_span_extender_0_windowed_slave arbitrationPriority {1}
    set_connection_parameter_value pcie_0.pb_pcie_rxm_m0/pcie_0.address_span_extender_0_windowed_slave baseAddress {0x0000}
    set_connection_parameter_value pcie_0.pb_pcie_rxm_m0/pcie_0.address_span_extender_0_windowed_slave defaultConnection {0}


    add_connection clk_0.clk pcie_0.clk clock

    add_connection clk_0.clk pio_rp_reset.clk clock
	
	add_connection iopll_0.outclk0 pcie_0.clk_125_in_clk clock
	
	add_connection arria10_hps_0.f2h_irq0 pcie_0.msgdma_0_csr_irq interrupt
    set_connection_parameter_value arria10_hps_0.f2h_irq0/pcie_0.msgdma_0_csr_irq irqNumber {4}

    add_connection arria10_hps_0.f2h_irq0 pcie_0.msi_to_gic_gen_0_interrupt_sender interrupt
    set_connection_parameter_value arria10_hps_0.f2h_irq0/pcie_0.msi_to_gic_gen_0_interrupt_sender irqNumber {3}

    add_connection arria10_hps_0.f2h_irq0 pcie_0.pcie_a10_hip_avmm_cra_irq interrupt
    set_connection_parameter_value arria10_hps_0.f2h_irq0/pcie_0.pcie_a10_hip_avmm_cra_irq irqNumber {5}
	
	add_connection clk_0.clk_reset pcie_0.reset reset

    add_connection clk_0.clk_reset iopll_0.reset reset

    add_connection clk_0.clk_reset pio_rp_reset.reset reset
	
	add_connection arria10_hps_0.h2f_reset pcie_0.reset reset

    add_connection arria10_hps_0.h2f_reset iopll_0.reset reset

    add_connection arria10_hps_0.h2f_reset pio_rp_reset.reset reset
}

  add_connection pb_lwh2f.m0 ILC.avalon_slave avalon
  set_connection_parameter_value pb_lwh2f.m0/ILC.avalon_slave arbitrationPriority {1}
  set_connection_parameter_value pb_lwh2f.m0/ILC.avalon_slave baseAddress {0x4000}
  set_connection_parameter_value pb_lwh2f.m0/ILC.avalon_slave defaultConnection {0}
  
  add_connection pb_lwh2f.m0 sysid_qsys_0.control_slave avalon
  set_connection_parameter_value pb_lwh2f.m0/sysid_qsys_0.control_slave arbitrationPriority {1}
  set_connection_parameter_value pb_lwh2f.m0/sysid_qsys_0.control_slave baseAddress {0x4210}
  set_connection_parameter_value pb_lwh2f.m0/sysid_qsys_0.control_slave defaultConnection {0}
  
  add_connection arria10_hps_0.h2f_lw_axi_master pb_lwh2f.s0 avalon
  set_connection_parameter_value arria10_hps_0.h2f_lw_axi_master/pb_lwh2f.s0 arbitrationPriority {1}
  set_connection_parameter_value arria10_hps_0.h2f_lw_axi_master/pb_lwh2f.s0 baseAddress {0x00100000}
  set_connection_parameter_value arria10_hps_0.h2f_lw_axi_master/pb_lwh2f.s0 defaultConnection {0}
  
  add_connection pb_lwh2f.m0 led_pio.s1 avalon
  set_connection_parameter_value pb_lwh2f.m0/led_pio.s1 arbitrationPriority {1}
  set_connection_parameter_value pb_lwh2f.m0/led_pio.s1 baseAddress {0x4200}
  set_connection_parameter_value pb_lwh2f.m0/led_pio.s1 defaultConnection {0}
  
  add_connection pb_lwh2f.m0 button_pio.s1 avalon
  set_connection_parameter_value pb_lwh2f.m0/button_pio.s1 arbitrationPriority {1}
  set_connection_parameter_value pb_lwh2f.m0/button_pio.s1 baseAddress {0x41f0}
  set_connection_parameter_value pb_lwh2f.m0/button_pio.s1 defaultConnection {0}
  
  add_connection pb_lwh2f.m0 dipsw_pio.s1 avalon
  set_connection_parameter_value pb_lwh2f.m0/dipsw_pio.s1 arbitrationPriority {1}
  set_connection_parameter_value pb_lwh2f.m0/dipsw_pio.s1 baseAddress {0x41e0}
  set_connection_parameter_value pb_lwh2f.m0/dipsw_pio.s1 defaultConnection {0}

  add_connection arria10_hps_0.h2f_axi_master onchip_memory2_0.s1 avalon
  set_connection_parameter_value arria10_hps_0.h2f_axi_master/onchip_memory2_0.s1 arbitrationPriority {1}
  set_connection_parameter_value arria10_hps_0.h2f_axi_master/onchip_memory2_0.s1 baseAddress {0x0000}
  set_connection_parameter_value arria10_hps_0.h2f_axi_master/onchip_memory2_0.s1 defaultConnection {0}

  add_connection hps_only_master.master arria10_hps_0.f2h_axi_slave avalon
  set_connection_parameter_value hps_only_master.master/arria10_hps_0.f2h_axi_slave arbitrationPriority {1}
  set_connection_parameter_value hps_only_master.master/arria10_hps_0.f2h_axi_slave baseAddress {0x0000}
  set_connection_parameter_value hps_only_master.master/arria10_hps_0.f2h_axi_slave defaultConnection {0}
  
  
  add_connection fpga_only_master.master pb_lwh2f.s0 avalon
  set_connection_parameter_value fpga_only_master.master/pb_lwh2f.s0 arbitrationPriority {1}
  set_connection_parameter_value fpga_only_master.master/pb_lwh2f.s0 baseAddress {0x00100000}
  set_connection_parameter_value fpga_only_master.master/pb_lwh2f.s0 defaultConnection {0}
  
  add_connection fpga_only_master.master onchip_memory2_0.s1 avalon
  set_connection_parameter_value fpga_only_master.master/onchip_memory2_0.s1 arbitrationPriority {1}
  set_connection_parameter_value fpga_only_master.master/onchip_memory2_0.s1 baseAddress {0x0000}
  set_connection_parameter_value fpga_only_master.master/onchip_memory2_0.s1 defaultConnection {0}
  
  
  add_connection clk_0.clk hps_only_master.clk clock
  
  add_connection clk_0.clk reset_bridge_0.clk clock
  
  add_connection clk_0.clk fpga_only_master.clk clock
  
  add_connection clk_0.clk pb_lwh2f.clk clock
  
  add_connection clk_0.clk sysid_qsys_0.clk clock
  
  add_connection clk_0.clk led_pio.clk clock
  
  add_connection clk_0.clk button_pio.clk clock
  
  add_connection clk_0.clk dipsw_pio.clk clock
  
  add_connection clk_0.clk ILC.clk clock
   
  add_connection clk_0.clk onchip_memory2_0.clk1 clock
  
  add_connection clk_0.clk arria10_hps_0.f2sdram1_clock clock
  
if {$fpga_dp == 1} {
  add_connection clock_bridge_0.out_clk arria10_hps_0.f2h_axi_clock clock
} else {
  add_connection clk_0.clk arria10_hps_0.f2h_axi_clock clock
}
  
  add_connection clk_0.clk arria10_hps_0.h2f_axi_clock clock
  
  add_connection clk_0.clk arria10_hps_0.h2f_lw_axi_clock clock

if {$hps_sdram == "D9RPL" || $hps_sdram == "D9PZN" || $hps_sdram == "D9RGX"} {
  add_connection arria10_hps_0.emif emif_a10_hps_0.hps_emif_conduit_end conduit
  set_connection_parameter_value arria10_hps_0.emif/emif_a10_hps_0.hps_emif_conduit_end endPort {}
  set_connection_parameter_value arria10_hps_0.emif/emif_a10_hps_0.hps_emif_conduit_end endPortLSB {0}
  set_connection_parameter_value arria10_hps_0.emif/emif_a10_hps_0.hps_emif_conduit_end startPort {}
  set_connection_parameter_value arria10_hps_0.emif/emif_a10_hps_0.hps_emif_conduit_end startPortLSB {0}
  set_connection_parameter_value arria10_hps_0.emif/emif_a10_hps_0.hps_emif_conduit_end width {0}
}
  
  add_connection arria10_hps_0.f2h_irq0 button_pio.irq interrupt
  set_connection_parameter_value arria10_hps_0.f2h_irq0/button_pio.irq irqNumber {0}
  
  add_connection arria10_hps_0.f2h_irq0 dipsw_pio.irq interrupt
  set_connection_parameter_value arria10_hps_0.f2h_irq0/dipsw_pio.irq irqNumber {1}
  
  add_connection ILC.irq button_pio.irq interrupt
  set_connection_parameter_value ILC.irq/button_pio.irq irqNumber {0}
  
  add_connection ILC.irq dipsw_pio.irq interrupt
  set_connection_parameter_value ILC.irq/dipsw_pio.irq irqNumber {1}
  
  
  add_connection clk_0.clk_reset hps_only_master.clk_reset reset
  
  add_connection clk_0.clk_reset fpga_only_master.clk_reset reset
    
  add_connection clk_0.clk_reset reset_bridge_0.in_reset reset
  
  add_connection clk_0.clk_reset pb_lwh2f.reset reset
  
  add_connection clk_0.clk_reset sysid_qsys_0.reset reset
  
  add_connection clk_0.clk_reset led_pio.reset reset
  
  add_connection clk_0.clk_reset button_pio.reset reset
  
  add_connection clk_0.clk_reset dipsw_pio.reset reset
  
  add_connection clk_0.clk_reset onchip_memory2_0.reset1 reset
  
  add_connection clk_0.clk_reset ILC.reset_n reset
  
  add_connection arria10_hps_0.h2f_reset hps_only_master.clk_reset reset
  
  add_connection arria10_hps_0.h2f_reset fpga_only_master.clk_reset reset
  
if {$hps_sdram == "D9RPL" || $hps_sdram == "D9PZN" || $hps_sdram == "D9RGX"} {
  add_connection arria10_hps_0.h2f_reset emif_a10_hps_0.global_reset_reset_sink reset
  add_connection clk_0.clk_reset emif_a10_hps_0.global_reset_reset_sink reset
}
  
  add_connection arria10_hps_0.h2f_reset reset_bridge_0.in_reset reset
  
  add_connection arria10_hps_0.h2f_reset pb_lwh2f.reset reset
  
  add_connection arria10_hps_0.h2f_reset sysid_qsys_0.reset reset
  
  add_connection arria10_hps_0.h2f_reset led_pio.reset reset
  
  add_connection arria10_hps_0.h2f_reset button_pio.reset reset
  
  add_connection arria10_hps_0.h2f_reset dipsw_pio.reset reset
  
  add_connection arria10_hps_0.h2f_reset onchip_memory2_0.reset1 reset
  
  add_connection arria10_hps_0.h2f_reset ILC.reset_n reset
  
if {$fast_trace == 1} {
  add_connection arria10_hps_0.trace_s2f_clk trace_wrapper_0.clock_sink clock
  
  add_connection clk_0.clk_reset trace_wrapper_0.reset_sink reset
  
  add_connection arria10_hps_0.h2f_reset trace_wrapper_0.reset_sink reset
  
  add_connection trace_wrapper_0.h2f_tpiu arria10_hps_0.trace conduit
  set_connection_parameter_value trace_wrapper_0.h2f_tpiu/arria10_hps_0.trace endPort {}
  set_connection_parameter_value trace_wrapper_0.h2f_tpiu/arria10_hps_0.trace endPortLSB {0}
  set_connection_parameter_value trace_wrapper_0.h2f_tpiu/arria10_hps_0.trace startPort {}
  set_connection_parameter_value trace_wrapper_0.h2f_tpiu/arria10_hps_0.trace startPortLSB {0}
  set_connection_parameter_value trace_wrapper_0.h2f_tpiu/arria10_hps_0.trace width {0}
}

  # exported interfaces
  add_interface clk_100 clock sink
  set_interface_property clk_100 EXPORT_OF clk_0.clk_in
if {$hps_sdram == "D9RPL" || $hps_sdram == "D9PZN" || $hps_sdram == "D9RGX"} {
  add_interface emif_a10_hps_0_mem_conduit_end conduit end
  set_interface_property emif_a10_hps_0_mem_conduit_end EXPORT_OF emif_a10_hps_0.mem_conduit_end
  add_interface emif_a10_hps_0_oct_conduit_end conduit end
  set_interface_property emif_a10_hps_0_oct_conduit_end EXPORT_OF emif_a10_hps_0.oct_conduit_end
  add_interface emif_a10_hps_0_pll_ref_clk_clock_sink clock sink
  set_interface_property emif_a10_hps_0_pll_ref_clk_clock_sink EXPORT_OF emif_a10_hps_0.pll_ref_clk_clock_sink
}
if {$hps_sdram_debug_enable} {
  add_connection clk_0.clk_reset emif_a10_hps_0.cal_debug_reset_reset_sink reset
  add_connection arria10_hps_0.h2f_reset emif_a10_hps_0.cal_debug_reset_reset_sink reset
  add_connection clk_0.clk emif_a10_hps_0.cal_debug_clk_clock_sink clock
  add_interface emif_uart conduit end
  set_interface_property emif_uart EXPORT_OF emif_a10_hps_0.emif_uart
}
  add_interface f2h_cold_reset_req reset sink
  set_interface_property f2h_cold_reset_req EXPORT_OF arria10_hps_0.f2h_cold_reset_req
  add_interface f2h_debug_reset_req reset sink
  set_interface_property f2h_debug_reset_req EXPORT_OF arria10_hps_0.f2h_debug_reset_req
  add_interface f2h_stm_hw_events conduit end
  set_interface_property f2h_stm_hw_events EXPORT_OF arria10_hps_0.f2h_stm_hw_events
  add_interface f2h_warm_reset_req reset sink
  set_interface_property f2h_warm_reset_req EXPORT_OF arria10_hps_0.f2h_warm_reset_req
  add_interface hps_fpga_reset reset source
  set_interface_property hps_fpga_reset EXPORT_OF reset_bridge_0.out_reset
  add_interface hps_io conduit end
  set_interface_property hps_io EXPORT_OF arria10_hps_0.hps_io
  add_interface pio_button_external_connection conduit end
  set_interface_property pio_button_external_connection EXPORT_OF button_pio.external_connection
  add_interface pio_dipsw_external_connection conduit end
  set_interface_property pio_dipsw_external_connection EXPORT_OF dipsw_pio.external_connection
  add_interface pio_led_external_connection conduit end
  set_interface_property pio_led_external_connection EXPORT_OF led_pio.external_connection
  add_interface reset reset sink
  set_interface_property reset EXPORT_OF clk_0.clk_in_reset
  add_interface h2f_gp conduit end
  set_interface_property h2f_gp EXPORT_OF arria10_hps_0.h2f_gp

if {$hps_sgmii == 1} {
  # required additional interrupts from PHY
  add_interface f2h_irq conduit end
  set_interface_property f2h_irq EXPORT_OF arria10_hps_0.f2h_irq1
  
  add_interface arria10_hps_0_emac_ptp_ref_clock clock sink
  set_interface_property arria10_hps_0_emac_ptp_ref_clock EXPORT_OF arria10_hps_0.emac_ptp_ref_clock
  add_interface ref_clk_125 clock sink
  
  # re-route I2C from FPGA to IO48
  add_interface arria10_hps_0_i2c1_scl_in clock sink
  set_interface_property arria10_hps_0_i2c1_scl_in EXPORT_OF arria10_hps_0.i2c1_scl_in
  add_interface arria10_hps_0_i2c1_clk clock source
  set_interface_property arria10_hps_0_i2c1_clk EXPORT_OF arria10_hps_0.i2c1_clk
  add_interface arria10_hps_0_i2c1 conduit end
  set_interface_property arria10_hps_0_i2c1 EXPORT_OF arria10_hps_0.i2c1
  add_interface arria10_hps_0_emac1 conduit end
  set_interface_property arria10_hps_0_emac1 EXPORT_OF arria10_hps_0.emac1
if {$SGMII_COUNT == 1} {
  set_interface_property ref_clk_125 EXPORT_OF sgmii_1.clk_125
} else {
  set_interface_property ref_clk_125 EXPORT_OF clock_bridge_0.in_clk
  for {set x 1} {$x<=$SGMII_COUNT} {incr x} {
  add_connection clock_bridge_0.out_clk sgmii_${x}.clk_125 clock
  }
}
	  
  for {set x 1} {$x<=$SGMII_COUNT} {incr x} {
  #### added to force exportation of mdc of hps, case:278470
  add_interface emac${x}_md_clk clock source
  set_interface_property emac${x}_md_clk EXPORT_OF arria10_hps_0.emac${x}_md_clk
  add_interface sgmii_${x}_emac_mdio conduit end
  set_interface_property sgmii_${x}_emac_mdio EXPORT_OF sgmii_${x}.emac_mdio
  add_interface sgmii_${x}_emac_ptp conduit end
  set_interface_property sgmii_${x}_emac_ptp EXPORT_OF sgmii_${x}.emac_ptp
  add_interface sgmii_${x}_tse_rx_is_lockedtoref conduit end
  set_interface_property sgmii_${x}_tse_rx_is_lockedtoref EXPORT_OF sgmii_${x}.tse_rx_is_lockedtoref
  add_interface sgmii_${x}_tse_rx_set_locktodata conduit end
  set_interface_property sgmii_${x}_tse_rx_set_locktodata EXPORT_OF sgmii_${x}.tse_rx_set_locktodata
  add_interface sgmii_${x}_tse_rx_set_locktoref conduit end
  set_interface_property sgmii_${x}_tse_rx_set_locktoref EXPORT_OF sgmii_${x}.tse_rx_set_locktoref
  add_interface sgmii_${x}_tse_serdes_control_connection conduit end
  set_interface_property sgmii_${x}_tse_serdes_control_connection EXPORT_OF sgmii_${x}.tse_serdes_control_connection
  add_interface sgmii_${x}_tse_serial_connection conduit end
  set_interface_property sgmii_${x}_tse_serial_connection EXPORT_OF sgmii_${x}.tse_serial_connection
  add_interface sgmii_${x}_tse_sgmii_status_connection conduit end
  set_interface_property sgmii_${x}_tse_sgmii_status_connection EXPORT_OF sgmii_${x}.tse_sgmii_status_connection
  add_interface sgmii_${x}_tse_status_led_connection conduit end
  set_interface_property sgmii_${x}_tse_status_led_connection EXPORT_OF sgmii_${x}.tse_status_led_connection
  add_interface sgmii_${x}_xcvr_reset_control_0_pll_select conduit end
  set_interface_property sgmii_${x}_xcvr_reset_control_0_pll_select EXPORT_OF sgmii_${x}.xcvr_reset_control_0_pll_select
  add_interface sgmii_${x}_xcvr_reset_control_0_rx_ready conduit end
  set_interface_property sgmii_${x}_xcvr_reset_control_0_rx_ready EXPORT_OF sgmii_${x}.xcvr_reset_control_0_rx_ready
  add_interface sgmii_${x}_xcvr_reset_control_0_tx_ready conduit end
  set_interface_property sgmii_${x}_xcvr_reset_control_0_tx_ready EXPORT_OF sgmii_${x}.xcvr_reset_control_0_tx_ready
  add_interface sgmii_${x}_emac conduit end
  set_interface_property sgmii_${x}_emac EXPORT_OF sgmii_${x}.emac
  }
}

if {$fpga_dp == 1} {
  add_interface display_port_video_pll_locked conduit end
  set_interface_property display_port_video_pll_locked EXPORT_OF display_port.video_pll_locked
  add_interface display_port_video_pll_outclk0 clock source
  set_interface_property display_port_video_pll_outclk0 EXPORT_OF display_port.video_pll_outclk0
  add_interface display_port_video_pll_outclk1 clock source
  set_interface_property display_port_video_pll_outclk1 EXPORT_OF display_port.video_pll_outclk1
  add_interface display_port_video_pll_outclk2 clock source
  set_interface_property display_port_video_pll_outclk2 EXPORT_OF display_port.video_pll_outclk2
  add_interface display_port_bitec_dp_0_clk_cal clock sink
  set_interface_property display_port_bitec_dp_0_clk_cal EXPORT_OF display_port.bitec_dp_0_clk_cal
  add_interface display_port_bitec_dp_0_tx conduit end
  set_interface_property display_port_bitec_dp_0_tx EXPORT_OF display_port.bitec_dp_0_tx
  add_interface display_port_bitec_dp_0_tx0_video_in conduit end
  set_interface_property display_port_bitec_dp_0_tx0_video_in EXPORT_OF display_port.bitec_dp_0_tx0_video_in
  add_interface display_port_bitec_dp_0_tx0_video_in_1 clock sink
  set_interface_property display_port_bitec_dp_0_tx0_video_in_1 EXPORT_OF display_port.bitec_dp_0_tx0_video_in_1
  add_interface display_port_bitec_dp_0_tx_analog_reconfig conduit end
  set_interface_property display_port_bitec_dp_0_tx_analog_reconfig EXPORT_OF display_port.bitec_dp_0_tx_analog_reconfig
  add_interface display_port_bitec_dp_0_tx_aux conduit end
  set_interface_property display_port_bitec_dp_0_tx_aux EXPORT_OF display_port.bitec_dp_0_tx_aux
  add_interface display_port_bitec_dp_0_tx_reconfig conduit end
  set_interface_property display_port_bitec_dp_0_tx_reconfig EXPORT_OF display_port.bitec_dp_0_tx_reconfig
  add_interface display_port_clk_16 clock sink
  set_interface_property display_port_clk_16 EXPORT_OF display_port.clk_16
  add_interface display_port_clk_vip_160 clock sink
  set_interface_property display_port_clk_vip_160 EXPORT_OF clock_bridge_0.in_clk
  add_interface display_port_cvo_clocked_video conduit end
  set_interface_property display_port_cvo_clocked_video EXPORT_OF display_port.cvo_clocked_video
  add_interface display_port_oc_i2c_master_0_conduit_start conduit end
  set_interface_property display_port_oc_i2c_master_0_conduit_start EXPORT_OF display_port.oc_i2c_master_0_conduit_start
  add_interface display_port_pio_0_external_connection conduit end
  set_interface_property display_port_pio_0_external_connection EXPORT_OF display_port.pio_0_external_connection
  add_interface display_port_xcvr_atx_pll_a10_0_mcgb_rst conduit end
  set_interface_property display_port_xcvr_atx_pll_a10_0_mcgb_rst EXPORT_OF display_port.xcvr_atx_pll_a10_0_mcgb_rst
  add_interface display_port_xcvr_atx_pll_a10_0_pll_cal_busy conduit end
  set_interface_property display_port_xcvr_atx_pll_a10_0_pll_cal_busy EXPORT_OF display_port.xcvr_atx_pll_a10_0_pll_cal_busy
  add_interface display_port_xcvr_atx_pll_a10_0_pll_locked conduit end
  set_interface_property display_port_xcvr_atx_pll_a10_0_pll_locked EXPORT_OF display_port.xcvr_atx_pll_a10_0_pll_locked
  add_interface display_port_xcvr_atx_pll_a10_0_pll_refclk0 clock sink
  set_interface_property display_port_xcvr_atx_pll_a10_0_pll_refclk0 EXPORT_OF display_port.xcvr_atx_pll_a10_0_pll_refclk0
  add_interface display_port_xcvr_atx_pll_a10_0_reconfig_avmm0 avalon slave
  set_interface_property display_port_xcvr_atx_pll_a10_0_reconfig_avmm0 EXPORT_OF display_port.xcvr_atx_pll_a10_0_reconfig_avmm0
  add_interface display_port_xcvr_atx_pll_a10_0_tx_serial_clk hssi_serial_clock source
  set_interface_property display_port_xcvr_atx_pll_a10_0_tx_serial_clk EXPORT_OF display_port.xcvr_atx_pll_a10_0_tx_serial_clk
  add_interface display_port_xcvr_native_a10_0_reconfig_avmm_ch0 avalon slave
  set_interface_property display_port_xcvr_native_a10_0_reconfig_avmm_ch0 EXPORT_OF display_port.xcvr_native_a10_0_reconfig_avmm_ch0
  add_interface display_port_xcvr_native_a10_0_tx_analogreset_ch0 conduit end
  set_interface_property display_port_xcvr_native_a10_0_tx_analogreset_ch0 EXPORT_OF display_port.xcvr_native_a10_0_tx_analogreset_ch0
  add_interface display_port_xcvr_native_a10_0_tx_analogreset_ch1 conduit end
  set_interface_property display_port_xcvr_native_a10_0_tx_analogreset_ch1 EXPORT_OF display_port.xcvr_native_a10_0_tx_analogreset_ch1
  add_interface display_port_xcvr_native_a10_0_tx_analogreset_ch2 conduit end
  set_interface_property display_port_xcvr_native_a10_0_tx_analogreset_ch2 EXPORT_OF display_port.xcvr_native_a10_0_tx_analogreset_ch2
  add_interface display_port_xcvr_native_a10_0_tx_analogreset_ch3 conduit end
  set_interface_property display_port_xcvr_native_a10_0_tx_analogreset_ch3 EXPORT_OF display_port.xcvr_native_a10_0_tx_analogreset_ch3
  add_interface display_port_xcvr_native_a10_0_tx_cal_busy_ch0 conduit end
  set_interface_property display_port_xcvr_native_a10_0_tx_cal_busy_ch0 EXPORT_OF display_port.xcvr_native_a10_0_tx_cal_busy_ch0
  add_interface display_port_xcvr_native_a10_0_tx_cal_busy_ch1 conduit end
  set_interface_property display_port_xcvr_native_a10_0_tx_cal_busy_ch1 EXPORT_OF display_port.xcvr_native_a10_0_tx_cal_busy_ch1
  add_interface display_port_xcvr_native_a10_0_tx_cal_busy_ch2 conduit end
  set_interface_property display_port_xcvr_native_a10_0_tx_cal_busy_ch2 EXPORT_OF display_port.xcvr_native_a10_0_tx_cal_busy_ch2
  add_interface display_port_xcvr_native_a10_0_tx_cal_busy_ch3 conduit end
  set_interface_property display_port_xcvr_native_a10_0_tx_cal_busy_ch3 EXPORT_OF display_port.xcvr_native_a10_0_tx_cal_busy_ch3
  add_interface display_port_xcvr_native_a10_0_tx_clkout_ch0 clock source
  set_interface_property display_port_xcvr_native_a10_0_tx_clkout_ch0 EXPORT_OF display_port.xcvr_native_a10_0_tx_clkout_ch0
  add_interface display_port_xcvr_native_a10_0_tx_clkout_ch1 clock source
  set_interface_property display_port_xcvr_native_a10_0_tx_clkout_ch1 EXPORT_OF display_port.xcvr_native_a10_0_tx_clkout_ch1
  add_interface display_port_xcvr_native_a10_0_tx_clkout_ch2 clock source
  set_interface_property display_port_xcvr_native_a10_0_tx_clkout_ch2 EXPORT_OF display_port.xcvr_native_a10_0_tx_clkout_ch2
  add_interface display_port_xcvr_native_a10_0_tx_clkout_ch3 clock source
  set_interface_property display_port_xcvr_native_a10_0_tx_clkout_ch3 EXPORT_OF display_port.xcvr_native_a10_0_tx_clkout_ch3
  add_interface display_port_xcvr_native_a10_0_tx_coreclkin_ch0 clock sink
  set_interface_property display_port_xcvr_native_a10_0_tx_coreclkin_ch0 EXPORT_OF display_port.xcvr_native_a10_0_tx_coreclkin_ch0
  add_interface display_port_xcvr_native_a10_0_tx_coreclkin_ch1 clock sink
  set_interface_property display_port_xcvr_native_a10_0_tx_coreclkin_ch1 EXPORT_OF display_port.xcvr_native_a10_0_tx_coreclkin_ch1
  add_interface display_port_xcvr_native_a10_0_tx_coreclkin_ch2 clock sink
  set_interface_property display_port_xcvr_native_a10_0_tx_coreclkin_ch2 EXPORT_OF display_port.xcvr_native_a10_0_tx_coreclkin_ch2
  add_interface display_port_xcvr_native_a10_0_tx_coreclkin_ch3 clock sink
  set_interface_property display_port_xcvr_native_a10_0_tx_coreclkin_ch3 EXPORT_OF display_port.xcvr_native_a10_0_tx_coreclkin_ch3
  add_interface display_port_xcvr_native_a10_0_tx_digitalreset_ch0 conduit end
  set_interface_property display_port_xcvr_native_a10_0_tx_digitalreset_ch0 EXPORT_OF display_port.xcvr_native_a10_0_tx_digitalreset_ch0
  add_interface display_port_xcvr_native_a10_0_tx_digitalreset_ch1 conduit end
  set_interface_property display_port_xcvr_native_a10_0_tx_digitalreset_ch1 EXPORT_OF display_port.xcvr_native_a10_0_tx_digitalreset_ch1
  add_interface display_port_xcvr_native_a10_0_tx_digitalreset_ch2 conduit end
  set_interface_property display_port_xcvr_native_a10_0_tx_digitalreset_ch2 EXPORT_OF display_port.xcvr_native_a10_0_tx_digitalreset_ch2
  add_interface display_port_xcvr_native_a10_0_tx_digitalreset_ch3 conduit end
  set_interface_property display_port_xcvr_native_a10_0_tx_digitalreset_ch3 EXPORT_OF display_port.xcvr_native_a10_0_tx_digitalreset_ch3
  add_interface display_port_xcvr_native_a10_0_tx_parallel_data_ch0 conduit end
  set_interface_property display_port_xcvr_native_a10_0_tx_parallel_data_ch0 EXPORT_OF display_port.xcvr_native_a10_0_tx_parallel_data_ch0
  add_interface display_port_xcvr_native_a10_0_tx_parallel_data_ch1 conduit end
  set_interface_property display_port_xcvr_native_a10_0_tx_parallel_data_ch1 EXPORT_OF display_port.xcvr_native_a10_0_tx_parallel_data_ch1
  add_interface display_port_xcvr_native_a10_0_tx_parallel_data_ch2 conduit end
  set_interface_property display_port_xcvr_native_a10_0_tx_parallel_data_ch2 EXPORT_OF display_port.xcvr_native_a10_0_tx_parallel_data_ch2
  add_interface display_port_xcvr_native_a10_0_tx_parallel_data_ch3 conduit end
  set_interface_property display_port_xcvr_native_a10_0_tx_parallel_data_ch3 EXPORT_OF display_port.xcvr_native_a10_0_tx_parallel_data_ch3
  add_interface display_port_xcvr_native_a10_0_tx_polinv_ch0 conduit end
  set_interface_property display_port_xcvr_native_a10_0_tx_polinv_ch0 EXPORT_OF display_port.xcvr_native_a10_0_tx_polinv_ch0
  add_interface display_port_xcvr_native_a10_0_tx_polinv_ch1 conduit end
  set_interface_property display_port_xcvr_native_a10_0_tx_polinv_ch1 EXPORT_OF display_port.xcvr_native_a10_0_tx_polinv_ch1
  add_interface display_port_xcvr_native_a10_0_tx_polinv_ch2 conduit end
  set_interface_property display_port_xcvr_native_a10_0_tx_polinv_ch2 EXPORT_OF display_port.xcvr_native_a10_0_tx_polinv_ch2
  add_interface display_port_xcvr_native_a10_0_tx_polinv_ch3 conduit end
  set_interface_property display_port_xcvr_native_a10_0_tx_polinv_ch3 EXPORT_OF display_port.xcvr_native_a10_0_tx_polinv_ch3
  add_interface display_port_xcvr_native_a10_0_tx_serial_data_ch0 conduit end
  set_interface_property display_port_xcvr_native_a10_0_tx_serial_data_ch0 EXPORT_OF display_port.xcvr_native_a10_0_tx_serial_data_ch0
  add_interface display_port_xcvr_native_a10_0_tx_serial_data_ch1 conduit end
  set_interface_property display_port_xcvr_native_a10_0_tx_serial_data_ch1 EXPORT_OF display_port.xcvr_native_a10_0_tx_serial_data_ch1
  add_interface display_port_xcvr_native_a10_0_tx_serial_data_ch2 conduit end
  set_interface_property display_port_xcvr_native_a10_0_tx_serial_data_ch2 EXPORT_OF display_port.xcvr_native_a10_0_tx_serial_data_ch2
  add_interface display_port_xcvr_native_a10_0_tx_serial_data_ch3 conduit end
  set_interface_property display_port_xcvr_native_a10_0_tx_serial_data_ch3 EXPORT_OF display_port.xcvr_native_a10_0_tx_serial_data_ch3
  add_interface display_port_xcvr_native_a10_0_unused_tx_parallel_data conduit end
  set_interface_property display_port_xcvr_native_a10_0_unused_tx_parallel_data EXPORT_OF display_port.xcvr_native_a10_0_unused_tx_parallel_data
  add_interface display_port_xcvr_reset_control_0_pll_locked conduit end
  set_interface_property display_port_xcvr_reset_control_0_pll_locked EXPORT_OF display_port.xcvr_reset_control_0_pll_locked
  add_interface display_port_xcvr_reset_control_0_pll_select conduit end
  set_interface_property display_port_xcvr_reset_control_0_pll_select EXPORT_OF display_port.xcvr_reset_control_0_pll_select
  add_interface display_port_xcvr_reset_control_0_reset reset sink
  set_interface_property display_port_xcvr_reset_control_0_reset EXPORT_OF display_port.xcvr_reset_control_0_reset
  add_interface display_port_xcvr_reset_control_0_tx_analogreset conduit end
  set_interface_property display_port_xcvr_reset_control_0_tx_analogreset EXPORT_OF display_port.xcvr_reset_control_0_tx_analogreset
  add_interface display_port_xcvr_reset_control_0_tx_cal_busy conduit end
  set_interface_property display_port_xcvr_reset_control_0_tx_cal_busy EXPORT_OF display_port.xcvr_reset_control_0_tx_cal_busy
  add_interface display_port_xcvr_reset_control_0_tx_digitalreset conduit end
  set_interface_property display_port_xcvr_reset_control_0_tx_digitalreset EXPORT_OF display_port.xcvr_reset_control_0_tx_digitalreset
  add_interface display_port_xcvr_reset_control_0_tx_ready conduit end
  set_interface_property display_port_xcvr_reset_control_0_tx_ready EXPORT_OF display_port.xcvr_reset_control_0_tx_ready
  if {$frame_reader == 0} {
    add_interface display_port_tpg_pio conduit end
    set_interface_property display_port_tpg_pio EXPORT_OF display_port.tpg_pio
    add_interface display_port_vesa_tpg conduit end
    set_interface_property display_port_vesa_tpg EXPORT_OF display_port.vesa_tpg
    # add_interface display_port_0_cvo_din avalon_streaming sink
    # set_interface_property display_port_0_cvo_din EXPORT_OF display_port_0.cvo_din
  }
}

if {$fpga_pcie == 1} {
	add_interface iopll_0_locked conduit end
    set_interface_property iopll_0_locked EXPORT_OF iopll_0.locked
    add_interface iopll_0_refclk clock sink
    set_interface_property iopll_0_refclk EXPORT_OF iopll_0.refclk
    add_interface pcie_0_coreclk_fanout_clk clock source
    set_interface_property pcie_0_coreclk_fanout_clk EXPORT_OF pcie_0.coreclk_fanout_clk
    add_interface pcie_0_coreclk_fanout_clk_reset reset source
    set_interface_property pcie_0_coreclk_fanout_clk_reset EXPORT_OF pcie_0.coreclk_fanout_clk_reset
    add_interface pcie_0_pcie_a10_hip_avmm_currentspeed conduit end
    set_interface_property pcie_0_pcie_a10_hip_avmm_currentspeed EXPORT_OF pcie_0.pcie_a10_hip_avmm_currentspeed
    add_interface pcie_0_pcie_a10_hip_avmm_hip_ctrl conduit end
    set_interface_property pcie_0_pcie_a10_hip_avmm_hip_ctrl EXPORT_OF pcie_0.pcie_a10_hip_avmm_hip_ctrl
    add_interface pcie_0_pcie_a10_hip_avmm_hip_pipe conduit end
    set_interface_property pcie_0_pcie_a10_hip_avmm_hip_pipe EXPORT_OF pcie_0.pcie_a10_hip_avmm_hip_pipe
    add_interface pcie_0_pcie_a10_hip_avmm_hip_serial conduit end
    set_interface_property pcie_0_pcie_a10_hip_avmm_hip_serial EXPORT_OF pcie_0.pcie_a10_hip_avmm_hip_serial
    add_interface pcie_0_pcie_a10_hip_avmm_hip_status conduit end
    set_interface_property pcie_0_pcie_a10_hip_avmm_hip_status EXPORT_OF pcie_0.pcie_a10_hip_avmm_hip_status
    add_interface pcie_0_pcie_a10_hip_avmm_npor conduit end
    set_interface_property pcie_0_pcie_a10_hip_avmm_npor EXPORT_OF pcie_0.pcie_a10_hip_avmm_npor

	add_interface pio_rp_reset_external_connection conduit end
    set_interface_property pio_rp_reset_external_connection EXPORT_OF pio_rp_reset.external_connection
}

if {$fast_trace == 1} {
  add_interface trace_wrapper_0_f2h_clk_in conduit end
  set_interface_property trace_wrapper_0_f2h_clk_in EXPORT_OF trace_wrapper_0.f2h_clk_in
  add_interface trace_wrapper_0_trace_data_out conduit end
  set_interface_property trace_wrapper_0_trace_data_out EXPORT_OF trace_wrapper_0.trace_data_out
  add_interface trace_wrapper_0_trace_clk_out clock source
  set_interface_property trace_wrapper_0_trace_clk_out EXPORT_OF trace_wrapper_0.trace_clk_out
}

	
  # interconnect requirements
  set_interconnect_requirement {$system} {qsys_mm.clockCrossingAdapter} {HANDSHAKE}
  set_interconnect_requirement {$system} {qsys_mm.maxAdditionalLatency} {4}
  set_interconnect_requirement {$system} {qsys_mm.burstAdapterImplementation} {GENERIC_CONVERTER}
  set_interconnect_requirement {$system} {qsys_mm.enableEccProtection} {FALSE}
  set_interconnect_requirement {$system} {qsys_mm.insertDefaultSlave} {FALSE}
  set_interconnect_requirement {hps_only_master.master} {qsys_mm.security} {SECURE}
  set_interconnect_requirement {mm_interconnect_0|arria10_hps_0_h2f_axi_master_agent.read_cp/router_001.sink} {qsys_mm.postTransform.pipelineCount} {1}
  set_interconnect_requirement {mm_interconnect_0|arria10_hps_0_h2f_axi_master_agent.write_cp/router.sink} {qsys_mm.postTransform.pipelineCount} {1}
  set_interconnect_requirement {mm_interconnect_0|router_001.src/cmd_demux_001.sink} {qsys_mm.postTransform.pipelineCount} {1}
  set_interconnect_requirement {mm_interconnect_0|rsp_mux.src/arria10_hps_0_h2f_axi_master_agent.write_rp} {qsys_mm.postTransform.pipelineCount} {1}
  set_interconnect_requirement {mm_interconnect_0|rsp_mux_001.src/arria10_hps_0_h2f_axi_master_agent.read_rp} {qsys_mm.postTransform.pipelineCount} {1}
  set_interconnect_requirement {mm_interconnect_2|arria10_hps_0_h2f_axi_master_agent.read_cp/router_001.sink} {qsys_mm.postTransform.pipelineCount} {1}
  set_interconnect_requirement {mm_interconnect_2|arria10_hps_0_h2f_axi_master_agent.write_cp/router.sink} {qsys_mm.postTransform.pipelineCount} {1}
  set_interconnect_requirement {mm_interconnect_2|router.src/pb_lwh2f_m0_limiter.cmd_sink} {qsys_mm.postTransform.pipelineCount} {1}
  set_interconnect_requirement {mm_interconnect_2|rsp_mux.src/arria10_hps_0_h2f_axi_master_agent.write_rp} {qsys_mm.postTransform.pipelineCount} {1}
  set_interconnect_requirement {mm_interconnect_2|rsp_mux_001.src/arria10_hps_0_h2f_axi_master_agent.read_rp} {qsys_mm.postTransform.pipelineCount} {1}

save_system ${qsys_name}.qsys
