# to use this script, 
# example command to execute this script file
#   tclsh create_ghrd_top.tcl

# --- alternatively, input arguments could be passed in to select other design variant. 
#    hps_sdram  : input of memory device FBGA code to identify EMIF configuration for targeted memory. 
#                 D9RPL = "MT41K512M16TNA-107" DDR3 Dual Ranks at 800MHz,
#                 D9PZN = "MT41J256M16HA-093" DDR3 Single Rank at 1066MHz,
#                 D9RGX = "MT40A256M16HA-093E:A" DDR4 Single Rank at 1066MHz 
#    hps_sdram_ecc : enable ECC on HPS SDRAM controller
#                    1 = enable, or
#                    0 = disable
#    hps_sgmii  : enable hps emac routing to FPGA as SGMII Enet
#                 1 = enable, or 
#                 0 = disable
#    boot_device: Select boot source between SDMMC, QSPI, NAND
#    fast_trace : enable trace x16 with FPGA IO
#                 1 = enable, or
#                 0 = disable

# example command to execute this script file
#   tclsh create_ghrd_qsys.tcl hps_sdram D9PZN




source $::env(QUARTUS_ROOTDIR)/../ip/altera/common/hw_tcl_packages/altera_terp.tcl

#package require altera_terp

source ./design_config.tcl

proc show_cmd_args {} {
  global HPS_SDRAM_DEVICE
  global HPS_SDRAM_ECC_ENABLE
  global SGMII_ENABLE
  global DISP_PORT_ENABLE
  global GEN3_ENABLE
  global BOOT_SOURCE
  global FTRACE_ENABLE
  global ADD_FRAME_READER
  global QSYS_NAME
  
  foreach {name val} $::argv {
     puts "-> Accepted parameter: $name,  \tValue: $val"
     if {$name == "hps_sdram"} {
        set HPS_SDRAM_DEVICE $val
        #puts "$HPS_SDRAM_DEVICE is inserted"
     }
     if {$name == "hps_sdram_ecc"} {
        set HPS_SDRAM_ECC_ENABLE $val
        #puts "$HPS_SDRAM_ECC_ENABLE is inserted"
     }
	 if {$name == "hps_sgmii"} {
        set SGMII_ENABLE $val
        #puts "$SGMII_ENABLE is inserted"
     }
	 if {$name == "fpga_dp"} {
        set DISP_PORT_ENABLE $val
        #puts "$DISP_PORT_ENABLE is inserted"
     }
	 if {$name == "frame_reader"} {
      set ADD_FRAME_READER $val
     }
	 if {$name == "fpga_pcie"} {
        set GEN3_ENABLE $val
        #puts "$GEN3_ENABLE is inserted"
     }
	 if {$name == "boot_device"} {
        set BOOT_SOURCE $val
        #puts "$$BOOT_SOURCE is inserted"
     }
	 if {$name == "fast_trace"} {
        set FTRACE_ENABLE $val
        #puts "$$FTRACE_ENABLE is inserted"
     }
     if {$name == "QSYS_NAME"} {
        set QSYS_NAME $val
        #puts "$$QSYS_NAME is inserted"
     }
  }

}
show_cmd_args


# path to the TERP template
set template_path "top_level_template.v.terp" 
# file handle for template
set template_fh [open $template_path] 
# template contents
set template   [read $template_fh] 
# we are done with the file so we should close it
close $template_fh 

# construct parameters value used in terp file
set param(SYS_TOP_NAME)           $SYS_TOP_NAME
set param(QSYS_NAME)              $QSYS_NAME
set param(HPS_SDRAM_DEVICE)       $HPS_SDRAM_DEVICE
set param(HPS_SDRAM_ECC_ENABLE)   $HPS_SDRAM_ECC_ENABLE
set param(HPS_SDRAM_DEBUG_ENABLE) $HPS_SDRAM_DEBUG_ENABLE
set param(DISP_PORT_ENABLE)       $DISP_PORT_ENABLE
set param(ADD_FRAME_READER)       $ADD_FRAME_READER
set param(SGMII_ENABLE)           $SGMII_ENABLE
set param(SGMII_COUNT)            $SGMII_COUNT
set param(GEN3_ENABLE)            $GEN3_ENABLE
set param(FTRACE_ENABLE)          $FTRACE_ENABLE
set param(BOOT_SOURCE)            $BOOT_SOURCE

set content [altera_terp $template param]
set fo [open "./${SYS_TOP_NAME}.v" "w"] 
puts $fo $content
close $fo

